"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var image_source_1 = require("tns-core-modules/image-source");
var types = require("tns-core-modules/utils/types");
var TNSWebGLExtensions_1 = require("./TNSWebGLExtensions");
var TNSImageAsset_1 = require("./TNSImageAsset");
var TNSWebGLRenderingContext = (function (_super) {
    __extends(TNSWebGLRenderingContext, _super);
    function TNSWebGLRenderingContext(context) {
        var _this = _super.call(this) || this;
        _this.context = context;
        return _this;
    }
    TNSWebGLRenderingContext.prototype.getJSArray = function (value) {
        var count = value.length;
        var array = [];
        for (var i = 0; i < count; i++) {
            array.push(value[i]);
        }
        return array;
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferHeight", {
        get: function () {
            return this.context.getDrawingBufferHeight();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferWidth", {
        get: function () {
            return this.context.getDrawingBufferWidth();
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        console.log(message, this.getError());
    };
    TNSWebGLRenderingContext.prototype.activeTexture = function (texture) {
        this._glCheckError('activeTexture');
        this.context.activeTexture(texture);
    };
    TNSWebGLRenderingContext.prototype.attachShader = function (program, shader) {
        this._glCheckError('attachShader');
        var value = program ? program.native : null;
        var value2 = shader ? shader.native : null;
        this.context.attachShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.bindAttribLocation = function (program, index, name) {
        this._glCheckError('bindAttribLocation');
        var value = program ? program.native : null;
        this.context.bindAttribLocation(value, index, name);
    };
    TNSWebGLRenderingContext.prototype.bindBuffer = function (target, buffer) {
        this._glCheckError('bindBuffer');
        var value = buffer ? buffer.native : null;
        this.context.bindBuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindFramebuffer = function (target, framebuffer) {
        this._glCheckError('bindFramebuffer');
        var value = framebuffer ? framebuffer.native : null;
        this.context.bindFramebuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindRenderbuffer = function (target, renderbuffer) {
        this._glCheckError('bindRenderbuffer');
        var value = renderbuffer ? renderbuffer.native : null;
        this.context.bindRenderbuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindTexture = function (target, texture) {
        this._glCheckError('bindTexture');
        var value = texture ? texture.native : null;
        this.context.bindTexture(target, value);
    };
    TNSWebGLRenderingContext.prototype.blendColor = function (red, green, blue, alpha) {
        this._glCheckError('blendColor');
        this.context.blendColor(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquationSeparate = function (modeRGB, modeAlpha) {
        this._glCheckError('blendEquationSeparate');
        this.context.blendEquationSeparate(modeRGB, modeAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquation = function (mode) {
        this._glCheckError('blendEquation');
        this.context.blendEquation(mode);
    };
    TNSWebGLRenderingContext.prototype.blendFuncSeparate = function (srcRGB, dstRGB, srcAlpha, dstAlpha) {
        if (srcRGB === void 0) { srcRGB = this.ONE; }
        if (dstRGB === void 0) { dstRGB = this.ZERO; }
        if (srcAlpha === void 0) { srcAlpha = this.ONE; }
        if (dstAlpha === void 0) { dstAlpha = this.ZERO; }
        this._glCheckError('blendFuncSeparate');
        this.context.blendFuncSeparate(srcRGB, dstRGB, srcAlpha, dstAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendFunc = function (sfactor, dfactor) {
        if (sfactor === void 0) { sfactor = this.ONE; }
        if (dfactor === void 0) { dfactor = this.ZERO; }
        this._glCheckError('blendFunc');
        this.context.blendFunc(sfactor, dfactor);
    };
    TNSWebGLRenderingContext.prototype.toNativeArray = function (value, type) {
        if (value && value.length && typeof type === 'string') {
            var size = value.length;
            var nativeArray = Array.create(type, size);
            for (var i = 0; i < size; i++) {
                nativeArray[i] = value[i];
            }
            return nativeArray;
        }
        return [];
    };
    TNSWebGLRenderingContext.prototype.bufferData = function (target, srcData, usage) {
        this._glCheckError('bufferData');
        if (typeof srcData === 'number') {
            this.context.bufferData(target, srcData, usage);
        }
        else if (srcData instanceof ArrayBuffer) {
            this.context.bufferData(target, this.toNativeArray(new Uint8Array(srcData.slice(0)), 'byte'), usage);
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Uint8Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'byte'), usage);
            }
            else if (srcData instanceof Uint16Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'short'), usage);
            }
            else if (srcData instanceof Uint32Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'int'), usage);
            }
            else if (srcData instanceof Float32Array) {
                this.context.bufferData(target, this.toNativeArray(srcData, 'float'), usage);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.bufferSubData = function (target, offset, srcData) {
        this._glCheckError('bufferSubData');
        if (srcData instanceof ArrayBuffer) {
            this.context.bufferSubData(target, offset, new Uint8Array(srcData.slice(0)));
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Uint8Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'byte'));
            }
            else if (srcData instanceof Uint16Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'short'));
            }
            else if (srcData instanceof Uint32Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'int'));
            }
            else if (srcData instanceof Float32Array) {
                this.context.bufferSubData(target, offset, this.toNativeArray(srcData, 'float'));
            }
        }
    };
    TNSWebGLRenderingContext.prototype.checkFramebufferStatus = function (target) {
        this._glCheckError('checkFramebufferStatus');
        return this.context.checkFramebufferStatus(target);
    };
    TNSWebGLRenderingContext.prototype.clearColor = function (red, green, blue, alpha) {
        this._glCheckError('clearColor');
        this.context.clearColor(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.clearDepth = function (depth) {
        this._glCheckError('clearDepth');
        this.context.clearDepth(depth);
    };
    TNSWebGLRenderingContext.prototype.clearStencil = function (stencil) {
        this._glCheckError('clearStencil');
        this.context.clearStencil(stencil);
    };
    TNSWebGLRenderingContext.prototype.clear = function (mask) {
        this._glCheckError('clear');
        this.context.clear(mask);
    };
    TNSWebGLRenderingContext.prototype.colorMask = function (red, green, blue, alpha) {
        this._glCheckError('colorMask');
        this.context.colorMask(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.commit = function () {
        this.context.commit();
    };
    TNSWebGLRenderingContext.prototype.compileShader = function (shader) {
        this._glCheckError('compileShader');
        var value = shader ? shader.native : null;
        this.context.compileShader(value);
    };
    TNSWebGLRenderingContext.prototype.compressedTexImage2D = function (target, level, internalformat, width, height, border, pixels) {
        this._glCheckError('compressedTexImage2D');
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexImage2D(target, level, internalformat, width, height, border, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.compressedTexSubImage2D = function (target, level, xoffset, yoffset, width, height, format, pixels) {
        this._glCheckError('compressedTexSubImage2D');
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.copyTexImage2D = function (target, level, internalformat, x, y, width, height, border) {
        this._glCheckError('copyTexImage2D');
        this.context.copyTexImage2D(target, level, internalformat, x, y, width, height, border);
    };
    TNSWebGLRenderingContext.prototype.copyTexSubImage2D = function (target, level, xoffset, yoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage2D');
        this.context.copyTexSubImage2D(target, level, xoffset, yoffset, x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.createBuffer = function () {
        this._glCheckError('createBuffer');
        var id = this.context.createBuffer();
        return new canvas_plugin_common_1.WebGLBuffer(id);
    };
    TNSWebGLRenderingContext.prototype.createFramebuffer = function () {
        this._glCheckError('createFramebuffer');
        return new canvas_plugin_common_1.WebGLFramebuffer(this.context.createFramebuffer());
    };
    TNSWebGLRenderingContext.prototype.createProgram = function () {
        this._glCheckError('createProgram');
        return new canvas_plugin_common_1.WebGLProgram(this.context.createProgram());
    };
    TNSWebGLRenderingContext.prototype.createRenderbuffer = function () {
        this._glCheckError('createRenderbuffer');
        return new canvas_plugin_common_1.WebGLRenderbuffer(this.context.createRenderbuffer());
    };
    TNSWebGLRenderingContext.prototype.createShader = function (type) {
        this._glCheckError('createShader');
        return new canvas_plugin_common_1.WebGLShader(this.context.createShader(type));
    };
    TNSWebGLRenderingContext.prototype.createTexture = function () {
        this._glCheckError('createTexture');
        return new canvas_plugin_common_1.WebGLTexture(this.context.createTexture());
    };
    TNSWebGLRenderingContext.prototype.cullFace = function (mode) {
        this._glCheckError('cullFace');
        this.context.cullFace(mode);
    };
    TNSWebGLRenderingContext.prototype.deleteBuffer = function (buffer) {
        this._glCheckError('deleteBuffer');
        var value = buffer ? buffer.native : null;
        this.context.deleteBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteFramebuffer = function (frameBuffer) {
        this._glCheckError('deleteFramebuffer');
        var value = frameBuffer ? frameBuffer.native : null;
        this.context.deleteFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteProgram = function (program) {
        this._glCheckError('deleteProgram');
        var value = program ? program.native : null;
        this.context.deleteProgram(value);
    };
    TNSWebGLRenderingContext.prototype.deleteRenderbuffer = function (renderBuffer) {
        this._glCheckError('deleteRenderbuffer');
        var value = renderBuffer ? renderBuffer.native : null;
        this.context.deleteRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteShader = function (shader) {
        this._glCheckError('deleteShader');
        var value = shader ? shader.native : null;
        this.context.deleteShader(value);
    };
    TNSWebGLRenderingContext.prototype.deleteTexture = function (texture) {
        this._glCheckError('deleteTexture');
        var value = texture ? texture.native : null;
        this.context.deleteTexture(value);
    };
    TNSWebGLRenderingContext.prototype.depthFunc = function (func) {
        this._glCheckError('depthFunc');
        this.context.depthFunc(func);
    };
    TNSWebGLRenderingContext.prototype.depthMask = function (flag) {
        this._glCheckError('depthMask');
        this.context.depthMask(flag);
    };
    TNSWebGLRenderingContext.prototype.depthRange = function (zNear, zFar) {
        this._glCheckError('depthRange');
        this.context.depthRange(zNear, zFar);
    };
    TNSWebGLRenderingContext.prototype.detachShader = function (program, shader) {
        this._glCheckError('detachShader');
        var value = program ? program.native : null;
        var value2 = shader ? shader.native : null;
        this.context.detachShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.disableVertexAttribArray = function (index) {
        this._glCheckError('disableVertexAttribArray');
        this.context.disableVertexAttribArray(index);
    };
    TNSWebGLRenderingContext.prototype.disable = function (cap) {
        this._glCheckError('disable');
        this.context.disable(cap);
    };
    TNSWebGLRenderingContext.prototype.drawArrays = function (mode, first, count) {
        this._glCheckError('drawArrays');
        this.context.drawArrays(mode, first, count);
    };
    TNSWebGLRenderingContext.prototype.drawElements = function (mode, count, type, offset) {
        this._glCheckError('drawElements');
        this.context.drawElements(mode, count, type, offset);
    };
    TNSWebGLRenderingContext.prototype.enableVertexAttribArray = function (index) {
        this._glCheckError('enableVertexAttribArray');
        this.context.enableVertexAttribArray(index);
    };
    TNSWebGLRenderingContext.prototype.enable = function (cap) {
        this._glCheckError('enable');
        this.context.enable(cap);
    };
    TNSWebGLRenderingContext.prototype.finish = function () {
        this._glCheckError('finish');
        this.context.finish();
    };
    TNSWebGLRenderingContext.prototype.flush = function () {
        this._glCheckError('flush');
        this.context.flush();
    };
    TNSWebGLRenderingContext.prototype.framebufferRenderbuffer = function (target, attachment, renderbuffertarget, renderbuffer) {
        this._glCheckError('framebufferRenderbuffer');
        var value = renderbuffer ? renderbuffer.native : null;
        this.context.framebufferRenderbuffer(target, attachment, renderbuffertarget, value);
    };
    TNSWebGLRenderingContext.prototype.framebufferTexture2D = function (target, attachment, textarget, texture, level) {
        this._glCheckError('framebufferTexture2D');
        var value = texture ? texture.native : null;
        this.context.framebufferTexture2D(target, attachment, textarget, value, level);
    };
    TNSWebGLRenderingContext.prototype.frontFace = function (mode) {
        this._glCheckError('frontFace');
        this.context.frontFace(mode);
    };
    TNSWebGLRenderingContext.prototype.generateMipmap = function (target) {
        this._glCheckError('generateMipmap');
        this.context.generateMipmap(target);
    };
    TNSWebGLRenderingContext.prototype.getActiveAttrib = function (program, index) {
        this._glCheckError('getActiveAttrib');
        var value = program ? program.native : null;
        var attrib = this.context.getActiveAttrib(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(attrib.getName(), attrib.getSize(), attrib.getType());
    };
    TNSWebGLRenderingContext.prototype.getActiveUniform = function (program, index) {
        this._glCheckError('getActiveUniform');
        var value = program ? program.native : null;
        var uniform = this.context.getActiveUniform(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(uniform.getName(), uniform.getSize(), uniform.getType());
    };
    TNSWebGLRenderingContext.prototype.getAttachedShaders = function (program) {
        this._glCheckError('getAttachedShaders');
        var value = program ? program.native : null;
        return this.getJSArray(this.context.getAttachedShaders(value)).map(function (shader) { return new canvas_plugin_common_1.WebGLShader(shader); });
        ;
    };
    TNSWebGLRenderingContext.prototype.getAttribLocation = function (program, name) {
        this._glCheckError('getAttribLocation');
        var value = program ? program.native : null;
        return this.context.getAttribLocation(value, name);
    };
    TNSWebGLRenderingContext.prototype.getBufferParameter = function (target, pname) {
        this._glCheckError('getBufferParameter');
        return this.context.getBufferParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getContextAttributes = function () {
        var attributes = this.context.getContextAttributes();
        var keys = attributes.keySet().toArray();
        var length = keys.length;
        var contextAttributes = {};
        for (var i = 0; i < length; i++) {
            var key = keys[i];
            contextAttributes[key] = attributes.get(key);
        }
        return contextAttributes;
    };
    TNSWebGLRenderingContext.prototype.getError = function () {
        return this.context.getError();
    };
    TNSWebGLRenderingContext.prototype.getExtension = function (name) {
        this._glCheckError('getExtension');
        var ext = this.context.getExtension(name);
        if (ext) {
            var classObj = types.getClass(ext);
            switch (classObj) {
                case 'com.github.triniwiz.canvas.extensions.EXT_blend_minmax':
                    return new TNSWebGLExtensions_1.EXT_blend_minmax(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_color_buffer_half_float':
                    return new TNSWebGLExtensions_1.EXT_color_buffer_half_float(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_disjoint_timer_query':
                    return new TNSWebGLExtensions_1.EXT_disjoint_timer_query(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_sRGB':
                    return new TNSWebGLExtensions_1.EXT_sRGB(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_shader_texture_lod':
                    return new TNSWebGLExtensions_1.EXT_shader_texture_lod(ext);
                case 'com.github.triniwiz.canvas.extensions.EXT_texture_filter_anisotropic':
                    return new TNSWebGLExtensions_1.EXT_texture_filter_anisotropic(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_element_index_uint':
                    return new TNSWebGLExtensions_1.OES_element_index_uint(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_standard_derivatives':
                    return new TNSWebGLExtensions_1.OES_standard_derivatives(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_float':
                    return new TNSWebGLExtensions_1.OES_texture_float(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_float_linear':
                    return new TNSWebGLExtensions_1.OES_texture_float_linear(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_half_float':
                    return new TNSWebGLExtensions_1.OES_texture_half_float(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_texture_half_float_linear':
                    return new TNSWebGLExtensions_1.OES_texture_half_float_linear(ext);
                case 'com.github.triniwiz.canvas.extensions.OES_vertex_array_object':
                    return new TNSWebGLExtensions_1.OES_vertex_array_object(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_color_buffer_float':
                    return new TNSWebGLExtensions_1.WEBGL_color_buffer_float(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_atc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_atc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_etc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_etc1':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc1(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_pvrtc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_pvrtc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_compressed_texture_s3tc':
                    return new TNSWebGLExtensions_1.WEBGL_compressed_texture_s3tc(ext);
                case 'com.github.triniwiz.canvas.extensions.WEBGL_lose_context':
                    return new TNSWebGLExtensions_1.WEBGL_lose_context(ext);
            }
        }
        return null;
    };
    TNSWebGLRenderingContext.prototype.getFramebufferAttachmentParameter = function (target, attachment, pname) {
        this._glCheckError('getFramebufferAttachmentParameter');
        var param = this.context.getFramebufferAttachmentParameter(target, attachment, pname);
        if (param.isRenderbuffer()) {
            return new canvas_plugin_common_1.WebGLRenderbuffer(param.getValue());
        }
        else if (param.isTexture()) {
            return new canvas_plugin_common_1.WebGLTexture(param.getValue());
        }
        return this.toPrimitive(param.getValue());
    };
    TNSWebGLRenderingContext.prototype.getParameter = function (pname) {
        this._glCheckError('getParameter');
        var value = this.context.getParameter(pname);
        switch (pname) {
            case this.COLOR_WRITEMASK:
            case this.COLOR_CLEAR_VALUE:
            case this.BLEND_COLOR:
            case this.ALIASED_LINE_WIDTH_RANGE:
            case this.ALIASED_POINT_SIZE_RANGE:
            case this.DEPTH_RANGE:
                return this.getJSArray(value);
            case this.ARRAY_BUFFER_BINDING:
            case this.ELEMENT_ARRAY_BUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLBuffer(value);
            case this.CURRENT_PROGRAM:
                return new canvas_plugin_common_1.WebGLProgram(value);
            case this.COMPRESSED_TEXTURE_FORMATS:
                return new Uint32Array(this.getJSArray(value));
            case this.RENDERBUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLRenderbuffer(value);
            case this.FRAMEBUFFER_BINDING:
                if (value) {
                    return new canvas_plugin_common_1.WebGLFramebuffer(value);
                }
                return null;
            case this.VIEWPORT:
            case this.SCISSOR_BOX:
            case this.MAX_VIEWPORT_DIMS:
                console.log('stuff', this.getJSArray(value));
                return new Int32Array(this.getJSArray(value));
            case this.TEXTURE_BINDING_CUBE_MAP:
            case this.TEXTURE_BINDING_2D:
                if (value) {
                    return new canvas_plugin_common_1.WebGLTexture(value);
                }
                return null;
            default:
                return value;
        }
    };
    TNSWebGLRenderingContext.prototype.getProgramInfoLog = function (program) {
        this._glCheckError('getProgramInfoLog');
        var value = program ? program.native : null;
        return this.context.getProgramInfoLog(value);
    };
    TNSWebGLRenderingContext.prototype.getProgramParameter = function (program, pname) {
        this._glCheckError('getProgramParameter');
        var value = program ? program.native : null;
        return this.toPrimitive(this.context.getProgramParameter(value, pname));
    };
    TNSWebGLRenderingContext.prototype.getRenderbufferParameter = function (target, pname) {
        this._glCheckError('getRenderbufferParameter');
        return this.context.getRenderbufferParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderInfoLog = function (shader) {
        this._glCheckError('getShaderInfoLog');
        var value = shader ? shader.native : null;
        return this.context.getShaderInfoLog(value);
    };
    TNSWebGLRenderingContext.prototype.toPrimitive = function (value) {
        if (value instanceof java.lang.Integer) {
            return value.intValue();
        }
        else if (value instanceof java.lang.Long) {
            return value.longValue();
        }
        else if (value instanceof java.lang.Short) {
            return value.shortValue();
        }
        else if (value instanceof java.lang.Byte) {
            return value.byteValue();
        }
        else if (value instanceof java.lang.Boolean) {
            return value.booleanValue();
        }
        else if (value instanceof java.lang.String) {
            return value.toString();
        }
        else if (value instanceof java.lang.Float) {
            return value.floatValue();
        }
        else if (value instanceof java.lang.Double) {
            return value.doubleValue();
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.getShaderParameter = function (shader, pname) {
        this._glCheckError('getShaderParameter');
        var value = shader ? shader.native : null;
        return this.toPrimitive(this.context.getShaderParameter(value, pname));
    };
    TNSWebGLRenderingContext.prototype.getShaderPrecisionFormat = function (shaderType, precisionType) {
        this._glCheckError('getShaderPrecisionFormat');
        var precision = this.context.getShaderPrecisionFormat(shaderType, precisionType);
        return new canvas_plugin_common_1.WebGLShaderPrecisionFormat(precision.getRangeMin(), precision.getRangeMax(), precision.getPrecision());
    };
    TNSWebGLRenderingContext.prototype.getShaderSource = function (shader) {
        this._glCheckError('getShaderSource');
        var value = shader ? shader.native : null;
        return this.context.getShaderSource(value);
    };
    TNSWebGLRenderingContext.prototype.getSupportedExtensions = function () {
        this._glCheckError('getSupportedExtensions');
        return this.getJSArray(this.context.getSupportedExtensions());
    };
    TNSWebGLRenderingContext.prototype.getTexParameter = function (target, pname) {
        this._glCheckError('getTexParameter');
        return this.context.getTexParameter(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getUniformLocation = function (program, name) {
        this._glCheckError('getUniformLocation');
        var value = program ? program.native : null;
        return new canvas_plugin_common_1.WebGLUniformLocation(this.context.getUniformLocation(value, name));
    };
    TNSWebGLRenderingContext.prototype.getUniform = function (program, location) {
        this._glCheckError('getUniform');
        var value = program ? program.native : null;
        var value2 = location ? location.native : null;
        var uniform = this.context.getUniform(value, value2);
        if (uniform && uniform.length) {
            return this.getJSArray(uniform);
        }
        return uniform;
    };
    TNSWebGLRenderingContext.prototype.getVertexAttribOffset = function (index, pname) {
        this._glCheckError('getVertexAttribOffset');
        return this.context.getVertexAttribOffset(index, pname);
    };
    TNSWebGLRenderingContext.prototype.getVertexAttrib = function (index, pname) {
        this._glCheckError('getVertexAttrib');
        var value = this.context.getVertexAttrib(index, pname);
        if (pname === this.CURRENT_VERTEX_ATTRIB) {
            return this.getJSArray(value);
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.hint = function (target, mode) {
        this._glCheckError('hint');
        this.context.hint(target, mode);
    };
    TNSWebGLRenderingContext.prototype.isBuffer = function (buffer) {
        this._glCheckError('isBuffer');
        var value = buffer ? buffer.native : null;
        return this.context.isBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isContextLost = function () {
        this._glCheckError('isContextLost');
        return this.context.isContextLost();
    };
    TNSWebGLRenderingContext.prototype.isEnabled = function (cap) {
        this._glCheckError('isEnabled');
        return this.context.isEnabled(cap);
    };
    TNSWebGLRenderingContext.prototype.isFramebuffer = function (framebuffer) {
        this._glCheckError('isFramebuffer');
        var value = framebuffer ? framebuffer.native : null;
        return this.context.isFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isProgram = function (program) {
        this._glCheckError('isProgram');
        var value = program ? program.native : null;
        return this.context.isProgram(value);
    };
    TNSWebGLRenderingContext.prototype.isRenderbuffer = function (renderbuffer) {
        this._glCheckError('isRenderbuffer');
        var value = renderbuffer ? renderbuffer.native : null;
        return this.context.isRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isShader = function (shader) {
        this._glCheckError('isShader');
        var value = shader ? shader.native : null;
        return this.context.isShader(value);
    };
    TNSWebGLRenderingContext.prototype.isTexture = function (texture) {
        this._glCheckError('isTexture');
        var value = texture ? texture.native : null;
        return this.context.isTexture(value);
    };
    TNSWebGLRenderingContext.prototype.lineWidth = function (width) {
        this._glCheckError('lineWidth');
        this.context.lineWidth(width);
    };
    TNSWebGLRenderingContext.prototype.linkProgram = function (program) {
        this._glCheckError('linkProgram');
        var value = program ? program.native : null;
        this.context.linkProgram(value);
    };
    TNSWebGLRenderingContext.prototype.pixelStorei = function (pname, param) {
        this._glCheckError('pixelStorei');
        if (pname === this.UNPACK_FLIP_Y_WEBGL || pname === this.UNPACK_PREMULTIPLY_ALPHA_WEBGL) {
            this.context.pixelStorei(pname, java.lang.Boolean.valueOf(param));
        }
        else if (pname === this.PACK_ALIGNMENT || pname === this.UNPACK_ALIGNMENT || this.UNPACK_COLORSPACE_CONVERSION_WEBGL) {
            this.context.pixelStorei(pname, java.lang.Integer.valueOf(param));
        }
        else {
            this.context.pixelStorei(pname, param);
        }
    };
    TNSWebGLRenderingContext.prototype.polygonOffset = function (factor, units) {
        this._glCheckError('polygonOffset');
        this.context.polygonOffset(factor, units);
    };
    TNSWebGLRenderingContext.prototype.readPixels = function (x, y, width, height, format, type, pixels) {
        this._glCheckError('readPixels');
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Uint8Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'byte'));
            }
            else if (pixels instanceof Uint16Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'short'));
            }
            else if (pixels instanceof Uint32Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'int'));
            }
            else if (pixels instanceof Float32Array) {
                this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(pixels, 'float'));
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.readPixels(x, y, width, height, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
        }
    };
    TNSWebGLRenderingContext.prototype.renderbufferStorage = function (target, internalFormat, width, height) {
        this._glCheckError('renderbufferStorage');
        if (internalFormat === this.DEPTH_STENCIL) {
            internalFormat = 0x88F0;
        }
        this.context.renderbufferStorage(target, internalFormat, width, height);
    };
    TNSWebGLRenderingContext.prototype.sampleCoverage = function (value, invert) {
        this._glCheckError('sampleCoverage');
        this.context.sampleCoverage(value, invert);
    };
    TNSWebGLRenderingContext.prototype.scissor = function (x, y, width, height) {
        this._glCheckError('scissor');
        this.context.scissor(x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.shaderSource = function (shader, source) {
        this._glCheckError('shaderSource');
        var value = shader ? shader.native : null;
        this.context.shaderSource(value, source ? source : '');
    };
    TNSWebGLRenderingContext.prototype.stencilFuncSeparate = function (face, func, ref, mask) {
        this._glCheckError('stencilFuncSeparate');
        this.context.stencilFuncSeparate(face, func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilFunc = function (func, ref, mask) {
        this._glCheckError('stencilFunc');
        this.context.stencilFunc(func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMaskSeparate = function (face, mask) {
        this._glCheckError('stencilMaskSeparate');
        this.context.stencilMaskSeparate(face, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMask = function (mask) {
        this._glCheckError('stencilMask');
        this.context.stencilMask(mask);
    };
    TNSWebGLRenderingContext.prototype.stencilOpSeparate = function (face, fail, zfail, zpass) {
        this._glCheckError('stencilOpSeparate');
        this.context.stencilOpSeparate(face, fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.stencilOp = function (fail, zfail, zpass) {
        this._glCheckError('stencilOp');
        this.context.stencilOp(fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.texImage2D = function (target, level, internalformat, width, height, border, format, type, pixels) {
        this._glCheckError('texImage2D');
        if (arguments.length === 9) {
            if (pixels && pixels.buffer instanceof ArrayBuffer) {
                if (pixels instanceof Uint8Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'byte'));
                }
                else if (pixels instanceof Uint16Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'short'));
                }
                else if (pixels instanceof Uint32Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'int'));
                }
                else if (pixels instanceof Float32Array) {
                    this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(pixels, 'float'));
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texImage2D(target, level, internalformat, width, height, border, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'float'));
            }
            else {
                this.context.texImage2D(target, level, internalformat, width, height, border, format, type, pixels);
            }
        }
        else if (arguments.length === 6) {
            if (border instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texImage2D(target, level, internalformat, width, height, border.native);
            }
            else if (border instanceof android.graphics.Bitmap) {
                this.context.texImage2D(target, level, internalformat, width, height, border);
            }
            else if (border instanceof image_source_1.ImageSource) {
                this.context.texImage2D(target, level, internalformat, width, height, border.android);
            }
            else if (border &&
                typeof border.tagName === 'string' &&
                border.tagName === 'IMG') {
                if (border._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._asset.native);
                }
                else if (border._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._imageSource.android);
                }
                else if (border._image instanceof android.graphics.Bitmap) {
                    this.context.texImage2D(target, level, internalformat, width, height, border._image);
                }
                else if (typeof border.src === 'string') {
                    this.context.texImage2D(target, level, internalformat, width, height, image_source_1.fromFile(border.src).android);
                }
            }
        }
    };
    TNSWebGLRenderingContext.prototype.texParameterf = function (target, pname, param) {
        this._glCheckError('texParameterf');
        this.context.texParameterf(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texParameteri = function (target, pname, param) {
        this._glCheckError('texParameteri');
        this.context.texParameteri(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texSubImage2D = function (target, level, xoffset, yoffset, width, height, format, type, pixels) {
        this._glCheckError('texSubImage2D');
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Uint8Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'byte'));
                }
                else if (pixels instanceof Uint16Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'short'));
                }
                else if (pixels instanceof Uint32Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'int'));
                }
                else if (pixels instanceof Float32Array) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(pixels, 'float'));
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, this.toNativeArray(new Uint8Array(pixels.slice(0)), 'byte'));
            }
        }
        else if (arguments.length === 7) {
            if (format instanceof android.graphics.Bitmap) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format);
            }
            else if (format instanceof image_source_1.ImageSource) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format.android);
            }
            else if (format instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format.native);
            }
            else if (format &&
                typeof format.tagName === 'string' &&
                format.tagName === 'IMG') {
                if (format._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._imageSource.android);
                }
                else if (format._image instanceof android.graphics.Bitmap) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._image);
                }
                else if (format._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, format._asset.native);
                }
                else if (typeof format.src === 'string') {
                    var result = image_source_1.fromFile(format.src);
                    this.context.texSubImage2D(target, level, xoffset, yoffset, width, height, result ? result.android : null);
                }
            }
        }
    };
    TNSWebGLRenderingContext.prototype.uniform1f = function (location, v0) {
        this._glCheckError('uniform1f');
        this.context.uniform1f(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform1iv = function (location, value) {
        this._glCheckError('uniform1iv');
        this.context.uniform1iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1fv = function (location, value) {
        this._glCheckError('uniform1fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniform1fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1i = function (location, v0) {
        this._glCheckError('uniform1i');
        this.context.uniform1i(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform2f = function (location, v0, v1) {
        this._glCheckError('uniform2f');
        this.context.uniform2f(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform2iv = function (location, value) {
        this._glCheckError('uniform2iv');
        this.context.uniform2iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2fv = function (location, value) {
        this._glCheckError('uniform2fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniform2fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2i = function (location, v0, v1) {
        this._glCheckError('uniform2i');
        this.context.uniform2i(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform3f = function (location, v0, v1, v2) {
        this._glCheckError('uniform3f');
        this.context.uniform3f(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform3iv = function (location, value) {
        this._glCheckError('uniform3iv');
        this.context.uniform3iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3fv = function (location, value) {
        this._glCheckError('uniform3fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniform3fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3i = function (location, v0, v1, v2) {
        this._glCheckError('uniform3i');
        this.context.uniform3i(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform4f = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4f');
        this.context.uniform4f(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniform4iv = function (location, value) {
        this._glCheckError('uniform4iv');
        this.context.uniform4iv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4fv = function (location, value) {
        this._glCheckError('uniform4fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniform4fv(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4i = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4i');
        this.context.uniform4i(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix2fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix2fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix2fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix3fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix3fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix3fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix4fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix4fv');
        value = this.toNativeArray(value, 'float');
        this.context.uniformMatrix4fv(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.useProgram = function (program) {
        this._glCheckError('useProgram');
        var value = program ? program.native : null;
        this.context.useProgram(value);
    };
    TNSWebGLRenderingContext.prototype.validateProgram = function (program) {
        this._glCheckError('validateProgram');
        var value = program ? program.native : null;
        this.context.validateProgram(value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1f = function (index, v0) {
        this._glCheckError('vertexAttrib1f');
        this.context.vertexAttrib1f(index, v0);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1fv = function (index, value) {
        this._glCheckError('vertexAttrib1fv');
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib1fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2f = function (index, v0, v1) {
        this._glCheckError('vertexAttrib2f');
        this.context.vertexAttrib2f(index, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2fv = function (index, value) {
        this._glCheckError('vertexAttrib2fv');
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib2fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3f = function (index, v0, v1, v2) {
        this._glCheckError('vertexAttrib3f');
        this.context.vertexAttrib3f(index, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3fv = function (index, value) {
        this._glCheckError('vertexAttrib3fv');
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib3fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4f = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttrib4f');
        this.context.vertexAttrib4f(index, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4fv = function (index, value) {
        this._glCheckError('vertexAttrib4fv');
        value = this.toNativeArray(value, 'float');
        this.context.vertexAttrib4fv(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttribPointer = function (index, size, type, normalized, stride, offset) {
        this._glCheckError('vertexAttribPointer');
        this.context.vertexAttribPointer(index, size, type, normalized, stride, offset);
    };
    TNSWebGLRenderingContext.prototype.viewport = function (x, y, width, height) {
        this._glCheckError('viewport');
        this.context.viewport(x, y, width, height);
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_CONSTANT_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_CONSTANT_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONSTANT_ALPHA", {
        get: function () {
            return this.context.CONSTANT_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_CONSTANT_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_CONSTANT_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONSTANT_COLOR", {
        get: function () {
            return this.context.CONSTANT_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_ALPHA_SATURATE", {
        get: function () {
            return this.context.SRC_ALPHA_SATURATE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_DST_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_DST_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DST_COLOR", {
        get: function () {
            return this.context.DST_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_DST_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DST_ALPHA", {
        get: function () {
            return this.context.DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_SRC_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_SRC_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_COLOR", {
        get: function () {
            return this.context.SRC_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_ALPHA", {
        get: function () {
            return this.context.SRC_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_SRC_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_SRC_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_ATTRIBUTES", {
        get: function () {
            return this.context.ACTIVE_ATTRIBUTES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_TEXTURE", {
        get: function () {
            return this.context.ACTIVE_TEXTURE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_UNIFORMS", {
        get: function () {
            return this.context.ACTIVE_UNIFORMS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALIASED_LINE_WIDTH_RANGE", {
        get: function () {
            return this.context.ALIASED_LINE_WIDTH_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALIASED_POINT_SIZE_RANGE", {
        get: function () {
            return this.context.ALIASED_POINT_SIZE_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALPHA", {
        get: function () {
            return this.context.ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALPHA_BITS", {
        get: function () {
            return this.context.ALPHA_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALWAYS", {
        get: function () {
            return this.context.ALWAYS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ARRAY_BUFFER", {
        get: function () {
            return this.context.ARRAY_BUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ATTACHED_SHADERS", {
        get: function () {
            return this.context.ATTACHED_SHADERS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BACK", {
        get: function () {
            return this.context.BACK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND", {
        get: function () {
            return this.context.BLEND;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_COLOR", {
        get: function () {
            return this.context.BLEND_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_DST_ALPHA", {
        get: function () {
            return this.context.BLEND_DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_DST_RGB", {
        get: function () {
            return this.context.BLEND_DST_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION", {
        get: function () {
            return this.context.BLEND_EQUATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION_ALPHA", {
        get: function () {
            return this.context.BLEND_EQUATION_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION_RGB", {
        get: function () {
            return this.context.BLEND_EQUATION_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_SRC_ALPHA", {
        get: function () {
            return this.context.BLEND_SRC_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_SRC_RGB", {
        get: function () {
            return this.context.BLEND_SRC_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLUE_BITS", {
        get: function () {
            return this.context.BLUE_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL", {
        get: function () {
            return this.context.BOOL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC2", {
        get: function () {
            return this.context.BOOL_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC3", {
        get: function () {
            return this.context.BOOL_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC4", {
        get: function () {
            return this.context.BOOL_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CCW", {
        get: function () {
            return this.context.CCW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CLAMP_TO_EDGE", {
        get: function () {
            return this.context.CLAMP_TO_EDGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT0", {
        get: function () {
            return this.context.COLOR_ATTACHMENT0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT0_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT0_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT10_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT10_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT11_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT11_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT12_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT12_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT13_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT13_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT14_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT14_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT15_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT15_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT1_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT1_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT2_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT2_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT3_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT3_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT4_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT4_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT5_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT5_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT6_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT6_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT7_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT7_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT8_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT8_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT9_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT9_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_BUFFER_BIT", {
        get: function () {
            return this.context.COLOR_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_CLEAR_VALUE", {
        get: function () {
            return this.context.COLOR_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_WRITEMASK", {
        get: function () {
            return this.context.COLOR_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPILE_STATUS", {
        get: function () {
            return this.context.COMPILE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_R11_EAC", {
        get: function () {
            return this.context.COMPRESSED_R11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RED_GREEN_RGTC2_EXT", {
        get: function () {
            return this.context.COMPRESSED_RED_GREEN_RGTC2_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RED_RGTC1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RED_RGTC1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RG11_EAC", {
        get: function () {
            return this.context.COMPRESSED_RG11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB8_ETC2", {
        get: function () {
            return this.context.COMPRESSED_RGB8_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2", {
        get: function () {
            return this.context.COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA8_ETC2_EAC", {
        get: function () {
            return this.context.COMPRESSED_RGBA8_ETC2_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_12x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_12x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_12x12_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_12x12_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_4x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_4x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_5x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_5x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_5x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_5x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_6x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_6x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_6x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_6x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x8_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x8_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ATC_EXPLICIT_ALPHA_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ATC_EXPLICIT_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ATC_INTERPOLATED_ALPHA_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ATC_INTERPOLATED_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_BPTC_UNORM_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_BPTC_UNORM_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_PVRTC_2BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGBA_PVRTC_2BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_PVRTC_4BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGBA_PVRTC_4BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT3_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT3_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT5_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT5_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_ATC_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGB_ATC_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_ETC1_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGB_ETC1_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_PVRTC_2BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGB_PVRTC_2BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_PVRTC_4BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGB_PVRTC_4BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_R11_EAC", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_R11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RED_RGTC1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RED_RGTC1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RG11_EAC", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RG11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ETC2_EAC", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ETC2_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ETC2", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_TEXTURE_FORMATS", {
        get: function () {
            return this.context.COMPRESSED_TEXTURE_FORMATS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONTEXT_LOST_WEBGL", {
        get: function () {
            return this.context.CONTEXT_LOST_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CULL_FACE", {
        get: function () {
            return this.context.CULL_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CULL_FACE_MODE", {
        get: function () {
            return this.context.CULL_FACE_MODE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CURRENT_PROGRAM", {
        get: function () {
            return this.context.CURRENT_PROGRAM;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CURRENT_VERTEX_ATTRIB", {
        get: function () {
            return this.context.CURRENT_VERTEX_ATTRIB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CW", {
        get: function () {
            return this.context.CW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DECR", {
        get: function () {
            return this.context.DECR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DECR_WRAP", {
        get: function () {
            return this.context.DECR_WRAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DELETE_STATUS", {
        get: function () {
            return this.context.DELETE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_ATTACHMENT", {
        get: function () {
            return this.context.DEPTH_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_BITS", {
        get: function () {
            return this.context.DEPTH_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_BUFFER_BIT", {
        get: function () {
            return this.context.DEPTH_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_CLEAR_VALUE", {
        get: function () {
            return this.context.DEPTH_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_COMPONENT16", {
        get: function () {
            return this.context.DEPTH_COMPONENT16;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_FUNC", {
        get: function () {
            return this.context.DEPTH_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_RANGE", {
        get: function () {
            return this.context.DEPTH_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_STENCIL", {
        get: function () {
            return this.context.DEPTH_STENCIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_STENCIL_ATTACHMENT", {
        get: function () {
            return this.context.DEPTH_STENCIL_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_TEST", {
        get: function () {
            return this.context.DEPTH_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_WRITEMASK", {
        get: function () {
            return this.context.DEPTH_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DITHER", {
        get: function () {
            return this.context.DITHER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DONT_CARE", {
        get: function () {
            return this.context.DONT_CARE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DYNAMIC_DRAW", {
        get: function () {
            return this.context.DYNAMIC_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ELEMENT_ARRAY_BUFFER", {
        get: function () {
            return this.context.ELEMENT_ARRAY_BUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ELEMENT_ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.ELEMENT_ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "EQUAL", {
        get: function () {
            return this.context.EQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FASTEST", {
        get: function () {
            return this.context.FASTEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT", {
        get: function () {
            return this.context.FLOAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT2", {
        get: function () {
            return this.context.FLOAT_MAT2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT3", {
        get: function () {
            return this.context.FLOAT_MAT3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT4", {
        get: function () {
            return this.context.FLOAT_MAT4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC2", {
        get: function () {
            return this.context.FLOAT_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC3", {
        get: function () {
            return this.context.FLOAT_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC4", {
        get: function () {
            return this.context.FLOAT_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAGMENT_SHADER", {
        get: function () {
            return this.context.FRAGMENT_SHADER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAGMENT_SHADER_DERIVATIVE_HINT_OES", {
        get: function () {
            return this.context.FRAGMENT_SHADER_DERIVATIVE_HINT_OES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER", {
        get: function () {
            return this.context.FRAMEBUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_NAME", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_OBJECT_NAME;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_BINDING", {
        get: function () {
            return this.context.FRAMEBUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_COMPLETE", {
        get: function () {
            return this.context.FRAMEBUFFER_COMPLETE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_ATTACHMENT", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_DIMENSIONS", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_DIMENSIONS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_UNSUPPORTED", {
        get: function () {
            return this.context.FRAMEBUFFER_UNSUPPORTED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT", {
        get: function () {
            return this.context.FRONT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT_AND_BACK", {
        get: function () {
            return this.context.FRONT_AND_BACK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT_FACE", {
        get: function () {
            return this.context.FRONT_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_ADD", {
        get: function () {
            return this.context.FUNC_ADD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_REVERSE_SUBTRACT", {
        get: function () {
            return this.context.FUNC_REVERSE_SUBTRACT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_SUBTRACT", {
        get: function () {
            return this.context.FUNC_SUBTRACT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GENERATE_MIPMAP_HINT", {
        get: function () {
            return this.context.GENERATE_MIPMAP_HINT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GEQUAL", {
        get: function () {
            return this.context.GEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GREATER", {
        get: function () {
            return this.context.GREATER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GREEN_BITS", {
        get: function () {
            return this.context.GREEN_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "IMPLEMENTATION_COLOR_READ_FORMAT", {
        get: function () {
            return this.context.IMPLEMENTATION_COLOR_READ_FORMAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "IMPLEMENTATION_COLOR_READ_TYPE", {
        get: function () {
            return this.context.IMPLEMENTATION_COLOR_READ_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INCR", {
        get: function () {
            return this.context.INCR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INCR_WRAP", {
        get: function () {
            return this.context.INCR_WRAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT", {
        get: function () {
            return this.context.INT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC2", {
        get: function () {
            return this.context.INT_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC3", {
        get: function () {
            return this.context.INT_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC4", {
        get: function () {
            return this.context.INT_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_ENUM", {
        get: function () {
            return this.context.INVALID_ENUM;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_FRAMEBUFFER_OPERATION", {
        get: function () {
            return this.context.INVALID_FRAMEBUFFER_OPERATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_OPERATION", {
        get: function () {
            return this.context.INVALID_OPERATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_VALUE", {
        get: function () {
            return this.context.INVALID_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVERT", {
        get: function () {
            return this.context.INVERT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "KEEP", {
        get: function () {
            return this.context.KEEP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LEQUAL", {
        get: function () {
            return this.context.LEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LESS", {
        get: function () {
            return this.context.LESS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR", {
        get: function () {
            return this.context.LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR_MIPMAP_LINEAR", {
        get: function () {
            return this.context.LINEAR_MIPMAP_LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR_MIPMAP_NEAREST", {
        get: function () {
            return this.context.LINEAR_MIPMAP_NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINES", {
        get: function () {
            return this.context.LINES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_LOOP", {
        get: function () {
            return this.context.LINE_LOOP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_STRIP", {
        get: function () {
            return this.context.LINE_STRIP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_WIDTH", {
        get: function () {
            return this.context.LINE_WIDTH;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINK_STATUS", {
        get: function () {
            return this.context.LINK_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LUMINANCE", {
        get: function () {
            return this.context.LUMINANCE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LUMINANCE_ALPHA", {
        get: function () {
            return this.context.LUMINANCE_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_COMBINED_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_COMBINED_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_CUBE_MAP_TEXTURE_SIZE", {
        get: function () {
            return this.context.MAX_CUBE_MAP_TEXTURE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_FRAGMENT_UNIFORM_VECTORS", {
        get: function () {
            return this.context.MAX_FRAGMENT_UNIFORM_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_RENDERBUFFER_SIZE", {
        get: function () {
            return this.context.MAX_RENDERBUFFER_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_TEXTURE_SIZE", {
        get: function () {
            return this.context.MAX_TEXTURE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VARYING_VECTORS", {
        get: function () {
            return this.context.MAX_VARYING_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_ATTRIBS", {
        get: function () {
            return this.context.MAX_VERTEX_ATTRIBS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_VERTEX_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_UNIFORM_VECTORS", {
        get: function () {
            return this.context.MAX_VERTEX_UNIFORM_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VIEWPORT_DIMS", {
        get: function () {
            return this.context.MAX_VIEWPORT_DIMS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MIRRORED_REPEAT", {
        get: function () {
            return this.context.MIRRORED_REPEAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST", {
        get: function () {
            return this.context.NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST_MIPMAP_LINEAR", {
        get: function () {
            return this.context.NEAREST_MIPMAP_LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST_MIPMAP_NEAREST", {
        get: function () {
            return this.context.NEAREST_MIPMAP_NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEVER", {
        get: function () {
            return this.context.NEVER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NICEST", {
        get: function () {
            return this.context.NICEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NOTEQUAL", {
        get: function () {
            return this.context.NOTEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NO_ERROR", {
        get: function () {
            return this.context.NO_ERROR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE", {
        get: function () {
            return this.context.ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "OUT_OF_MEMORY", {
        get: function () {
            return this.context.OUT_OF_MEMORY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "PACK_ALIGNMENT", {
        get: function () {
            return this.context.PACK_ALIGNMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POINTS", {
        get: function () {
            return this.context.POINTS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_FACTOR", {
        get: function () {
            return this.context.POLYGON_OFFSET_FACTOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_FILL", {
        get: function () {
            return this.context.POLYGON_OFFSET_FILL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_UNITS", {
        get: function () {
            return this.context.POLYGON_OFFSET_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RED_BITS", {
        get: function () {
            return this.context.RED_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER", {
        get: function () {
            return this.context.RENDERBUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_ALPHA_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_ALPHA_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_BINDING", {
        get: function () {
            return this.context.RENDERBUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_BLUE_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_BLUE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_DEPTH_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_DEPTH_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_GREEN_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_GREEN_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_HEIGHT", {
        get: function () {
            return this.context.RENDERBUFFER_HEIGHT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_INTERNAL_FORMAT", {
        get: function () {
            return this.context.RENDERBUFFER_INTERNAL_FORMAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_RED_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_RED_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_STENCIL_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_STENCIL_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_WIDTH", {
        get: function () {
            return this.context.RENDERBUFFER_WIDTH;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERER", {
        get: function () {
            return this.context.RENDERER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "REPEAT", {
        get: function () {
            return this.context.REPEAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "REPLACE", {
        get: function () {
            return this.context.REPLACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB", {
        get: function () {
            return this.context.RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB32F_EXT", {
        get: function () {
            return this.context.RGB32F_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB565", {
        get: function () {
            return this.context.RGB565;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB5_A1", {
        get: function () {
            return this.context.RGB5_A1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA", {
        get: function () {
            return this.context.RGBA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA32F_EXT", {
        get: function () {
            return this.context.RGBA32F_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA4", {
        get: function () {
            return this.context.RGBA4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLER_2D", {
        get: function () {
            return this.context.SAMPLER_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLER_CUBE", {
        get: function () {
            return this.context.SAMPLER_CUBE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLES", {
        get: function () {
            return this.context.SAMPLES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_ALPHA_TO_COVERAGE", {
        get: function () {
            return this.context.SAMPLE_ALPHA_TO_COVERAGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_BUFFERS", {
        get: function () {
            return this.context.SAMPLE_BUFFERS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE", {
        get: function () {
            return this.context.SAMPLE_COVERAGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE_INVERT", {
        get: function () {
            return this.context.SAMPLE_COVERAGE_INVERT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE_VALUE", {
        get: function () {
            return this.context.SAMPLE_COVERAGE_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SCISSOR_BOX", {
        get: function () {
            return this.context.SCISSOR_BOX;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SCISSOR_TEST", {
        get: function () {
            return this.context.SCISSOR_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SHADER_TYPE", {
        get: function () {
            return this.context.SHADER_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SHADING_LANGUAGE_VERSION", {
        get: function () {
            return this.context.SHADING_LANGUAGE_VERSION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRGB8_ALPHA8_EXT", {
        get: function () {
            return this.context.SRGB8_ALPHA8_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STATIC_DRAW", {
        get: function () {
            return this.context.STATIC_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_ATTACHMENT", {
        get: function () {
            return this.context.STENCIL_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_FAIL", {
        get: function () {
            return this.context.STENCIL_BACK_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_FUNC", {
        get: function () {
            return this.context.STENCIL_BACK_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_PASS_DEPTH_FAIL", {
        get: function () {
            return this.context.STENCIL_BACK_PASS_DEPTH_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_PASS_DEPTH_PASS", {
        get: function () {
            return this.context.STENCIL_BACK_PASS_DEPTH_PASS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_REF", {
        get: function () {
            return this.context.STENCIL_BACK_REF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_VALUE_MASK", {
        get: function () {
            return this.context.STENCIL_BACK_VALUE_MASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_WRITEMASK", {
        get: function () {
            return this.context.STENCIL_BACK_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BITS", {
        get: function () {
            return this.context.STENCIL_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BUFFER_BIT", {
        get: function () {
            return this.context.STENCIL_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_CLEAR_VALUE", {
        get: function () {
            return this.context.STENCIL_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_FAIL", {
        get: function () {
            return this.context.STENCIL_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_FUNC", {
        get: function () {
            return this.context.STENCIL_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_INDEX8", {
        get: function () {
            return this.context.STENCIL_INDEX8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_PASS_DEPTH_FAIL", {
        get: function () {
            return this.context.STENCIL_PASS_DEPTH_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_PASS_DEPTH_PASS", {
        get: function () {
            return this.context.STENCIL_PASS_DEPTH_PASS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_REF", {
        get: function () {
            return this.context.STENCIL_REF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_TEST", {
        get: function () {
            return this.context.STENCIL_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_VALUE_MASK", {
        get: function () {
            return this.context.STENCIL_VALUE_MASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_WRITEMASK", {
        get: function () {
            return this.context.STENCIL_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STREAM_DRAW", {
        get: function () {
            return this.context.STREAM_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SUBPIXEL_BITS", {
        get: function () {
            return this.context.SUBPIXEL_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE0", {
        get: function () {
            return this.context.TEXTURE0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE1", {
        get: function () {
            return this.context.TEXTURE1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE10", {
        get: function () {
            return this.context.TEXTURE10;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE11", {
        get: function () {
            return this.context.TEXTURE11;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE12", {
        get: function () {
            return this.context.TEXTURE12;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE13", {
        get: function () {
            return this.context.TEXTURE13;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE14", {
        get: function () {
            return this.context.TEXTURE14;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE15", {
        get: function () {
            return this.context.TEXTURE15;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE16", {
        get: function () {
            return this.context.TEXTURE16;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE17", {
        get: function () {
            return this.context.TEXTURE17;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE18", {
        get: function () {
            return this.context.TEXTURE18;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE19", {
        get: function () {
            return this.context.TEXTURE19;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE2", {
        get: function () {
            return this.context.TEXTURE2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE20", {
        get: function () {
            return this.context.TEXTURE20;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE21", {
        get: function () {
            return this.context.TEXTURE21;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE22", {
        get: function () {
            return this.context.TEXTURE22;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE23", {
        get: function () {
            return this.context.TEXTURE23;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE24", {
        get: function () {
            return this.context.TEXTURE24;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE25", {
        get: function () {
            return this.context.TEXTURE25;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE26", {
        get: function () {
            return this.context.TEXTURE26;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE27", {
        get: function () {
            return this.context.TEXTURE27;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE28", {
        get: function () {
            return this.context.TEXTURE28;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE29", {
        get: function () {
            return this.context.TEXTURE29;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE3", {
        get: function () {
            return this.context.TEXTURE3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE30", {
        get: function () {
            return this.context.TEXTURE30;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE31", {
        get: function () {
            return this.context.TEXTURE31;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE4", {
        get: function () {
            return this.context.TEXTURE4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE5", {
        get: function () {
            return this.context.TEXTURE5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE6", {
        get: function () {
            return this.context.TEXTURE6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE7", {
        get: function () {
            return this.context.TEXTURE7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE8", {
        get: function () {
            return this.context.TEXTURE8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE9", {
        get: function () {
            return this.context.TEXTURE9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_2D", {
        get: function () {
            return this.context.TEXTURE_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_BINDING_2D", {
        get: function () {
            return this.context.TEXTURE_BINDING_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_BINDING_CUBE_MAP", {
        get: function () {
            return this.context.TEXTURE_BINDING_CUBE_MAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_X", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_X;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Y", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_Y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Z", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_Z;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_X", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_X;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Y", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_Y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Z", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_Z;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MAG_FILTER", {
        get: function () {
            return this.context.TEXTURE_MAG_FILTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MAX_ANISOTROPY_EXT", {
        get: function () {
            return this.context.TEXTURE_MAX_ANISOTROPY_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MIN_FILTER", {
        get: function () {
            return this.context.TEXTURE_MIN_FILTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_WRAP_S", {
        get: function () {
            return this.context.TEXTURE_WRAP_S;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_WRAP_T", {
        get: function () {
            return this.context.TEXTURE_WRAP_T;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLES", {
        get: function () {
            return this.context.TRIANGLES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLE_FAN", {
        get: function () {
            return this.context.TRIANGLE_FAN;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLE_STRIP", {
        get: function () {
            return this.context.TRIANGLE_STRIP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_ALIGNMENT", {
        get: function () {
            return this.context.UNPACK_ALIGNMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_COLORSPACE_CONVERSION_WEBGL", {
        get: function () {
            return this.context.UNPACK_COLORSPACE_CONVERSION_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_FLIP_Y_WEBGL", {
        get: function () {
            return this.context.UNPACK_FLIP_Y_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_PREMULTIPLY_ALPHA_WEBGL", {
        get: function () {
            return this.context.UNPACK_PREMULTIPLY_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_BYTE", {
        get: function () {
            return this.context.UNSIGNED_BYTE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_INT", {
        get: function () {
            return this.context.UNSIGNED_INT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT", {
        get: function () {
            return this.context.UNSIGNED_SHORT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_4_4_4_4", {
        get: function () {
            return this.context.UNSIGNED_SHORT_4_4_4_4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_5_5_5_1", {
        get: function () {
            return this.context.UNSIGNED_SHORT_5_5_5_1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_5_6_5", {
        get: function () {
            return this.context.UNSIGNED_SHORT_5_6_5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VALIDATE_STATUS", {
        get: function () {
            return this.context.VALIDATE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VENDOR", {
        get: function () {
            return this.context.VENDOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERSION", {
        get: function () {
            return this.context.VERSION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_ENABLED", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_ENABLED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_NORMALIZED", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_NORMALIZED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_POINTER", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_POINTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_SIZE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_STRIDE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_STRIDE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_TYPE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_SHADER", {
        get: function () {
            return this.context.VERTEX_SHADER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VIEWPORT", {
        get: function () {
            return this.context.VIEWPORT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ZERO", {
        get: function () {
            return this.context.ZERO;
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.isDebug = false;
    return TNSWebGLRenderingContext;
}(canvas_plugin_common_1.TNSWebGLRenderingContextBase));
exports.TNSWebGLRenderingContext = TNSWebGLRenderingContext;
//# sourceMappingURL=TNSWebGLRenderingContext.android.js.map