import {
    TNSWebGLRenderingContextBase,
    WebGLActiveInfo,
    WebGLBuffer,
    WebGLFramebuffer,
    WebGLProgram,
    WebGLRenderbuffer,
    WebGLShader,
    WebGLShaderPrecisionFormat,
    WebGLTexture,
    WebGLUniformLocation
} from './canvas-plugin.common';

export declare class TNSWebGLRenderingContext extends TNSWebGLRenderingContextBase {
    private context;

    constructor(context: any);

    readonly native: any;
    readonly drawingBufferHeight: number;
    readonly drawingBufferWidth: number;

    activeTexture(texture: number): void;

    attachShader(program: WebGLProgram, shader: WebGLShader): void;

    bindAttribLocation(program: WebGLProgram, index: number, name: string): void;

    bindBuffer(target: number, buffer: WebGLBuffer): void;

    bindFramebuffer(target: number, framebuffer: WebGLFramebuffer): void;

    bindRenderbuffer(target: number, renderbuffer: WebGLRenderbuffer): void;

    bindTexture(target: number, texture: WebGLTexture): void;

    blendColor(red: number, green: number, blue: number, alpha: number): void;

    blendEquationSeparate(modeRGB: number, modeAlpha: number): void;

    blendEquation(mode: number): void;

    blendFuncSeparate(srcRGB?: number, dstRGB?: number, srcAlpha?: number, dstAlpha?: number): void;

    blendFunc(sfactor?: number, dfactor?: number): void;

    protected toNativeArray(value: any[] | ArrayBufferView, type: string): any;

    bufferData(target: number, size: number, usage: number): void;
    bufferData(target: number, srcData: ArrayBuffer | ArrayBufferView, usage: number): void;

    bufferSubData(target: number, offset: number, srcData: ArrayBuffer | ArrayBufferView): void;

    checkFramebufferStatus(target: number): number;

    clearColor(red: number, green: number, blue: number, alpha: number): void;

    clearDepth(depth: number): void;

    clearStencil(stencil: number): void;

    clear(mask: number): void;

    colorMask(red: boolean, green: boolean, blue: boolean, alpha: boolean): void;

    commit(): void;

    compileShader(shader: WebGLShader): void;

    compressedTexImage2D(target: number, level: number, internalformat: number, width: number, height: number, border: number, pixels: ArrayBufferView): void;

    compressedTexSubImage2D(target: number, level: number, xoffset: number, yoffset: number, width: number, height: number, format: number, pixels: ArrayBufferView): void;

    copyTexImage2D(target: number, level: number, internalformat: number, x: number, y: number, width: number, height: number, border: number): void;

    copyTexSubImage2D(target: number, level: number, xoffset: number, yoffset: number, x: number, y: number, width: number, height: number): void;

    createBuffer(): WebGLBuffer;

    createFramebuffer(): WebGLFramebuffer;

    createProgram(): WebGLProgram;

    createRenderbuffer(): WebGLRenderbuffer;

    createShader(type: number): WebGLShader;

    createTexture(): WebGLTexture;

    cullFace(mode: number): void;

    deleteBuffer(buffer: WebGLBuffer): void;

    deleteFramebuffer(frameBuffer: WebGLFramebuffer): void;

    deleteProgram(program: WebGLProgram): void;

    deleteRenderbuffer(renderBuffer: WebGLRenderbuffer): void;

    deleteShader(shader: WebGLRenderbuffer): void;

    deleteTexture(texture: WebGLTexture): void;

    depthFunc(func: number): void;

    depthMask(flag: boolean): void;

    depthRange(zNear: number, zFar: number): void;

    detachShader(program: WebGLProgram, shader: WebGLShader): void;

    disableVertexAttribArray(index: number): void;

    disable(cap: number): void;

    drawArrays(mode: number, first: number, count: number): void;

    drawElements(mode: number, count: number, type: number, offset: number): void;

    enableVertexAttribArray(index: number): void;

    enable(cap: number): void;

    finish(): void;

    flush(): void;

    framebufferRenderbuffer(target: number, attachment: number, renderbuffertarget: number, renderbuffer: WebGLRenderbuffer): void;

    framebufferTexture2D(target: number, attachment: number, textarget: number, texture: WebGLTexture, level: number): void;

    frontFace(mode: number): void;

    generateMipmap(target: number): void;

    getActiveAttrib(program: WebGLProgram, index: number): WebGLActiveInfo;

    getActiveUniform(program: WebGLProgram, index: number): WebGLActiveInfo;

    getAttachedShaders(program: WebGLProgram): WebGLShader[];

    getAttribLocation(program: WebGLProgram, name: string): number;

    getBufferParameter(target: number, pname: number): number;

    getContextAttributes(): any;

    getError(): number;

    getExtension(name: string): any;

    getFramebufferAttachmentParameter(target: number, attachment: number, pname: number): number | WebGLRenderbuffer | WebGLTexture;

    protected getJSArray(nativeArray: any): any[];

    getParameter(pname: number): number[] | number | WebGLBuffer | WebGLProgram | WebGLFramebuffer | WebGLRenderbuffer | WebGLTexture | Uint32Array | Int32Array | null;

    getProgramInfoLog(program: WebGLProgram): string;

    getProgramParameter(program: WebGLProgram, pname: number): number | boolean;

    getRenderbufferParameter(target: number, pname: number): number;

    getShaderInfoLog(shader: WebGLShader): string;

    getShaderParameter(shader: WebGLShader, pname: number): boolean | number;

    getShaderPrecisionFormat(shaderType: number, precisionType: number): WebGLShaderPrecisionFormat;

    getShaderSource(shader: WebGLShader): string;

    getSupportedExtensions(): string[];

    getTexParameter(target: number, pname: number): number;

    getUniformLocation(program: WebGLProgram, name: string): WebGLUniformLocation;

    getUniform(program: WebGLProgram, location: WebGLUniformLocation): any;

    getVertexAttribOffset(index: number, pname: number): number;

    getVertexAttrib(index: number, pname: number): number[] | boolean | number;

    hint(target: number, mode: number): void;

    isBuffer(buffer: WebGLBuffer): boolean;

    isContextLost(): boolean;

    isEnabled(cap: number): boolean;

    isFramebuffer(framebuffer: WebGLFramebuffer): boolean;

    isProgram(program: WebGLProgram): boolean;

    isRenderbuffer(renderbuffer: WebGLRenderbuffer): boolean;

    isShader(shader: WebGLShader): boolean;

    isTexture(texture: WebGLTexture): boolean;

    lineWidth(width: number): void;

    linkProgram(program: WebGLProgram): void;

    pixelStorei(pname: number, param: any): void;

    polygonOffset(factor: number, units: number): void;

    readPixels(x: number, y: number, width: number, height: number, format: number, type: number, pixels: ArrayBufferView): void;

    renderbufferStorage(target: number, internalFormat: number, width: number, height: number): void;

    sampleCoverage(value: number, invert: boolean): void;

    scissor(x: number, y: number, width: number, height: number): void;

    shaderSource(shader: WebGLShader, source: string): void;

    stencilFuncSeparate(face: number, func: number, ref: number, mask: number): void;

    stencilFunc(func: number, ref: number, mask: number): void;

    stencilMaskSeparate(face: number, mask: number): void;

    stencilMask(mask: number): void;

    stencilOpSeparate(face: number, fail: number, zfail: number, zpass: number): void;

    stencilOp(fail: number, zfail: number, zpass: number): void;

    texImage2D(target: number, level: number, internalformat: number, format: number, type: number, pixels?: any): void;
    texImage2D(target: number, level: number, internalformat: number, width: number, height: number, border: number, format: number, type: number, pixels: ArrayBufferView): void;

    texParameterf(target: number, pname: number, param: number): void;

    texParameteri(target: number, pname: number, param: number): void;

    texSubImage2D(target: number, level: number, xoffset: number, yoffset: number, width: number, height: number, format: number, type: number, pixels?: ArrayBufferView): void;
    texSubImage2D(target: number, level: number, xoffset: number, yoffset: number, format: number, type: number, pixels?: any): void;

    uniform1f(location: WebGLUniformLocation, v0: number): void;

    uniform1iv(location: WebGLUniformLocation, value: number[]): void;

    uniform1fv(location: WebGLUniformLocation, value: number[]): void;

    uniform1i(location: WebGLUniformLocation, v0: number): void;

    uniform2f(location: WebGLUniformLocation, v0: number, v1: number): void;

    uniform2iv(location: WebGLUniformLocation, value: number[]): void;

    uniform2fv(location: WebGLUniformLocation, value: number[]): void;

    uniform2i(location: WebGLUniformLocation, v0: number, v1: number): void;

    uniform3f(location: WebGLUniformLocation, v0: number, v1: number, v2: number): void;

    uniform3iv(location: WebGLUniformLocation, value: number[]): void;

    uniform3fv(location: WebGLUniformLocation, value: number[]): void;

    uniform3i(location: WebGLUniformLocation, v0: number, v1: number, v2: number): void;

    uniform4f(location: WebGLUniformLocation, v0: number, v1: number, v2: number, v3: number): void;

    uniform4iv(location: WebGLUniformLocation, value: number[]): void;

    uniform4fv(location: WebGLUniformLocation, value: number[]): void;

    uniform4i(location: WebGLUniformLocation, v0: number, v1: number, v2: number, v3: number): void;

    uniformMatrix2fv(location: WebGLUniformLocation, transpose: boolean, value: number[]): void;

    uniformMatrix3fv(location: WebGLUniformLocation, transpose: boolean, value: number[]): void;

    uniformMatrix4fv(location: WebGLUniformLocation, transpose: boolean, value: number[]): void;

    useProgram(program: WebGLProgram): void;

    validateProgram(program: WebGLProgram): void;

    vertexAttrib1f(index: number, v0: number): void;

    vertexAttrib1fv(index: number, value: number[]): void;

    vertexAttrib2f(index: number, v0: number, v1: number): void;

    vertexAttrib2fv(index: number, value: number[]): void;

    vertexAttrib3f(index: number, v0: number, v1: number, v2: number): void;

    vertexAttrib3fv(index: number, value: number[]): void;

    vertexAttrib4f(index: number, v0: number, v1: number, v2: number, v3: number): void;

    vertexAttrib4fv(index: number, value: number[]): void;

    vertexAttribPointer(index: number, size: number, type: number, normalized: boolean, stride: number, offset: number): void;

    viewport(x: number, y: number, width: number, height: number): void;

    readonly ONE_MINUS_CONSTANT_ALPHA: number;
    readonly CONSTANT_ALPHA: number;
    readonly ONE_MINUS_CONSTANT_COLOR: number;
    readonly CONSTANT_COLOR: number;
    readonly SRC_ALPHA_SATURATE: number;
    readonly ONE_MINUS_DST_COLOR: number;
    readonly DST_COLOR: number;
    readonly ONE_MINUS_DST_ALPHA: number;
    readonly DST_ALPHA: number;
    readonly ONE_MINUS_SRC_COLOR: number;
    readonly SRC_COLOR: number;
    readonly SRC_ALPHA: number;
    readonly ONE_MINUS_SRC_ALPHA: number;
    readonly ACTIVE_ATTRIBUTES: number;
    readonly ACTIVE_TEXTURE: number;
    readonly ACTIVE_UNIFORMS: number;
    readonly ALIASED_LINE_WIDTH_RANGE: number;
    readonly ALIASED_POINT_SIZE_RANGE: number;
    readonly ALPHA: number;
    readonly ALPHA_BITS: number;
    readonly ALWAYS: number;
    readonly ARRAY_BUFFER: number;
    readonly ARRAY_BUFFER_BINDING: number;
    readonly ATTACHED_SHADERS: number;
    readonly BACK: number;
    readonly BLEND: number;
    readonly BLEND_COLOR: number;
    readonly BLEND_DST_ALPHA: number;
    readonly BLEND_DST_RGB: number;
    readonly BLEND_EQUATION: number;
    readonly BLEND_EQUATION_ALPHA: number;
    readonly BLEND_EQUATION_RGB: number;
    readonly BLEND_SRC_ALPHA: number;
    readonly BLEND_SRC_RGB: number;
    readonly BLUE_BITS: number;
    readonly BOOL: number;
    readonly BOOL_VEC2: number;
    readonly BOOL_VEC3: number;
    readonly BOOL_VEC4: number;
    readonly CCW: number;
    readonly CLAMP_TO_EDGE: number;
    readonly COLOR_ATTACHMENT0: number;
    readonly COLOR_ATTACHMENT0_WEBGL: number;
    readonly COLOR_ATTACHMENT10_WEBGL: number;
    readonly COLOR_ATTACHMENT11_WEBGL: number;
    readonly COLOR_ATTACHMENT12_WEBGL: number;
    readonly COLOR_ATTACHMENT13_WEBGL: number;
    readonly COLOR_ATTACHMENT14_WEBGL: number;
    readonly COLOR_ATTACHMENT15_WEBGL: number;
    readonly COLOR_ATTACHMENT1_WEBGL: number;
    readonly COLOR_ATTACHMENT2_WEBGL: number;
    readonly COLOR_ATTACHMENT3_WEBGL: number;
    readonly COLOR_ATTACHMENT4_WEBGL: number;
    readonly COLOR_ATTACHMENT5_WEBGL: number;
    readonly COLOR_ATTACHMENT6_WEBGL: number;
    readonly COLOR_ATTACHMENT7_WEBGL: number;
    readonly COLOR_ATTACHMENT8_WEBGL: number;
    readonly COLOR_ATTACHMENT9_WEBGL: number;
    readonly COLOR_BUFFER_BIT: number;
    readonly COLOR_CLEAR_VALUE: number;
    readonly COLOR_WRITEMASK: number;
    readonly COMPILE_STATUS: number;
    readonly COMPRESSED_R11_EAC: number;
    readonly COMPRESSED_RED_GREEN_RGTC2_EXT: number;
    readonly COMPRESSED_RED_RGTC1_EXT: number;
    readonly COMPRESSED_RG11_EAC: number;
    readonly COMPRESSED_RGB8_ETC2: number;
    readonly COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2: number;
    readonly COMPRESSED_RGBA8_ETC2_EAC: number;
    readonly COMPRESSED_RGBA_ASTC_10x10_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_10x5_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_10x6_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_12x10_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_12x12_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_4x4_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_5x4_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_5x5_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_6x5_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_6x6_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_8x5_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_8x6_KHR: number;
    readonly COMPRESSED_RGBA_ASTC_8x8_KHR: number;
    readonly COMPRESSED_RGBA_ATC_EXPLICIT_ALPHA_WEBGL: number;
    readonly COMPRESSED_RGBA_ATC_INTERPOLATED_ALPHA_WEBGL: number;
    readonly COMPRESSED_RGBA_BPTC_UNORM_EXT: number;
    readonly COMPRESSED_RGBA_PVRTC_2BPPV1_IMG: number;
    readonly COMPRESSED_RGBA_PVRTC_4BPPV1_IMG: number;
    readonly COMPRESSED_RGBA_S3TC_DXT1_EXT: number;
    readonly COMPRESSED_RGBA_S3TC_DXT3_EXT: number;
    readonly COMPRESSED_RGBA_S3TC_DXT5_EXT: number;
    readonly COMPRESSED_RGB_ATC_WEBGL: number;
    readonly COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT: number;
    readonly COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT: number;
    readonly COMPRESSED_RGB_ETC1_WEBGL: number;
    readonly COMPRESSED_RGB_PVRTC_2BPPV1_IMG: number;
    readonly COMPRESSED_RGB_PVRTC_4BPPV1_IMG: number;
    readonly COMPRESSED_RGB_S3TC_DXT1_EXT: number;
    readonly COMPRESSED_SIGNED_R11_EAC: number;
    readonly COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT: number;
    readonly COMPRESSED_SIGNED_RED_RGTC1_EXT: number;
    readonly COMPRESSED_SIGNED_RG11_EAC: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR: number;
    readonly COMPRESSED_SRGB8_ALPHA8_ETC2_EAC: number;
    readonly COMPRESSED_SRGB8_ETC2: number;
    readonly COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2: number;
    readonly COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT: number;
    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT: number;
    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT: number;
    readonly COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT: number;
    readonly COMPRESSED_SRGB_S3TC_DXT1_EXT: number;
    readonly COMPRESSED_TEXTURE_FORMATS: number;
    readonly CONTEXT_LOST_WEBGL: number;
    readonly CULL_FACE: number;
    readonly CULL_FACE_MODE: number;
    readonly CURRENT_PROGRAM: number;
    readonly CURRENT_VERTEX_ATTRIB: number;
    readonly CW: number;
    readonly DECR: number;
    readonly DECR_WRAP: number;
    readonly DELETE_STATUS: number;
    readonly DEPTH_ATTACHMENT: number;
    readonly DEPTH_BITS: number;
    readonly DEPTH_BUFFER_BIT: number;
    readonly DEPTH_CLEAR_VALUE: number;
    readonly DEPTH_COMPONENT16: number;
    readonly DEPTH_FUNC: number;
    readonly DEPTH_RANGE: number;
    readonly DEPTH_STENCIL: number;
    readonly DEPTH_STENCIL_ATTACHMENT: number;
    readonly DEPTH_TEST: number;
    readonly DEPTH_WRITEMASK: number;
    readonly DITHER: number;
    readonly DONT_CARE: number;
    readonly DYNAMIC_DRAW: number;
    readonly ELEMENT_ARRAY_BUFFER: number;
    readonly ELEMENT_ARRAY_BUFFER_BINDING: number;
    readonly EQUAL: number;
    readonly FASTEST: number;
    readonly FLOAT: number;
    readonly FLOAT_MAT2: number;
    readonly FLOAT_MAT3: number;
    readonly FLOAT_MAT4: number;
    readonly FLOAT_VEC2: number;
    readonly FLOAT_VEC3: number;
    readonly FLOAT_VEC4: number;
    readonly FRAGMENT_SHADER: number;
    readonly FRAGMENT_SHADER_DERIVATIVE_HINT_OES: number;
    readonly FRAMEBUFFER: number;
    readonly FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT: number;
    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_NAME: number;
    readonly FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE: number;
    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE: number;
    readonly FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL: number;
    readonly FRAMEBUFFER_BINDING: number;
    readonly FRAMEBUFFER_COMPLETE: number;
    readonly FRAMEBUFFER_INCOMPLETE_ATTACHMENT: number;
    readonly FRAMEBUFFER_INCOMPLETE_DIMENSIONS: number;
    readonly FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT: number;
    readonly FRAMEBUFFER_UNSUPPORTED: number;
    readonly FRONT: number;
    readonly FRONT_AND_BACK: number;
    readonly FRONT_FACE: number;
    readonly FUNC_ADD: number;
    readonly FUNC_REVERSE_SUBTRACT: number;
    readonly FUNC_SUBTRACT: number;
    readonly GENERATE_MIPMAP_HINT: number;
    readonly GEQUAL: number;
    readonly GREATER: number;
    readonly GREEN_BITS: number;
    readonly IMPLEMENTATION_COLOR_READ_FORMAT: number;
    readonly IMPLEMENTATION_COLOR_READ_TYPE: number;
    readonly INCR: number;
    readonly INCR_WRAP: number;
    readonly INT: number;
    readonly INT_VEC2: number;
    readonly INT_VEC3: number;
    readonly INT_VEC4: number;
    readonly INVALID_ENUM: number;
    readonly INVALID_FRAMEBUFFER_OPERATION: number;
    readonly INVALID_OPERATION: number;
    readonly INVALID_VALUE: number;
    readonly INVERT: number;
    readonly KEEP: number;
    readonly LEQUAL: number;
    readonly LESS: number;
    readonly LINEAR: number;
    readonly LINEAR_MIPMAP_LINEAR: number;
    readonly LINEAR_MIPMAP_NEAREST: number;
    readonly LINES: number;
    readonly LINE_LOOP: number;
    readonly LINE_STRIP: number;
    readonly LINE_WIDTH: number;
    readonly LINK_STATUS: number;
    readonly LUMINANCE: number;
    readonly LUMINANCE_ALPHA: number;
    readonly MAX_COMBINED_TEXTURE_IMAGE_UNITS: number;
    readonly MAX_CUBE_MAP_TEXTURE_SIZE: number;
    readonly MAX_FRAGMENT_UNIFORM_VECTORS: number;
    readonly MAX_RENDERBUFFER_SIZE: number;
    readonly MAX_TEXTURE_IMAGE_UNITS: number;
    readonly MAX_TEXTURE_SIZE: number;
    readonly MAX_VARYING_VECTORS: number;
    readonly MAX_VERTEX_ATTRIBS: number;
    readonly MAX_VERTEX_TEXTURE_IMAGE_UNITS: number;
    readonly MAX_VERTEX_UNIFORM_VECTORS: number;
    readonly MAX_VIEWPORT_DIMS: number;
    readonly MIRRORED_REPEAT: number;
    readonly NEAREST: number;
    readonly NEAREST_MIPMAP_LINEAR: number;
    readonly NEAREST_MIPMAP_NEAREST: number;
    readonly NEVER: number;
    readonly NICEST: number;
    readonly NOTEQUAL: number;
    readonly NO_ERROR: number;
    readonly ONE: number;
    readonly OUT_OF_MEMORY: number;
    readonly PACK_ALIGNMENT: number;
    readonly POINTS: number;
    readonly POLYGON_OFFSET_FACTOR: number;
    readonly POLYGON_OFFSET_FILL: number;
    readonly POLYGON_OFFSET_UNITS: number;
    readonly RED_BITS: number;
    readonly RENDERBUFFER: number;
    readonly RENDERBUFFER_ALPHA_SIZE: number;
    readonly RENDERBUFFER_BINDING: number;
    readonly RENDERBUFFER_BLUE_SIZE: number;
    readonly RENDERBUFFER_DEPTH_SIZE: number;
    readonly RENDERBUFFER_GREEN_SIZE: number;
    readonly RENDERBUFFER_HEIGHT: number;
    readonly RENDERBUFFER_INTERNAL_FORMAT: number;
    readonly RENDERBUFFER_RED_SIZE: number;
    readonly RENDERBUFFER_STENCIL_SIZE: number;
    readonly RENDERBUFFER_WIDTH: number;
    readonly RENDERER: number;
    readonly REPEAT: number;
    readonly REPLACE: number;
    readonly RGB: number;
    readonly RGB32F_EXT: number;
    readonly RGB565: number;
    readonly RGB5_A1: number;
    readonly RGBA: number;
    readonly RGBA32F_EXT: number;
    readonly RGBA4: number;
    readonly SAMPLER_2D: number;
    readonly SAMPLER_CUBE: number;
    readonly SAMPLES: number;
    readonly SAMPLE_ALPHA_TO_COVERAGE: number;
    readonly SAMPLE_BUFFERS: number;
    readonly SAMPLE_COVERAGE: number;
    readonly SAMPLE_COVERAGE_INVERT: number;
    readonly SAMPLE_COVERAGE_VALUE: number;
    readonly SCISSOR_BOX: number;
    readonly SCISSOR_TEST: number;
    readonly SHADER_TYPE: number;
    readonly SHADING_LANGUAGE_VERSION: number;
    readonly SRGB8_ALPHA8_EXT: number;
    readonly STATIC_DRAW: number;
    readonly STENCIL_ATTACHMENT: number;
    readonly STENCIL_BACK_FAIL: number;
    readonly STENCIL_BACK_FUNC: number;
    readonly STENCIL_BACK_PASS_DEPTH_FAIL: number;
    readonly STENCIL_BACK_PASS_DEPTH_PASS: number;
    readonly STENCIL_BACK_REF: number;
    readonly STENCIL_BACK_VALUE_MASK: number;
    readonly STENCIL_BACK_WRITEMASK: number;
    readonly STENCIL_BITS: number;
    readonly STENCIL_BUFFER_BIT: number;
    readonly STENCIL_CLEAR_VALUE: number;
    readonly STENCIL_FAIL: number;
    readonly STENCIL_FUNC: number;
    readonly STENCIL_INDEX8: number;
    readonly STENCIL_PASS_DEPTH_FAIL: number;
    readonly STENCIL_PASS_DEPTH_PASS: number;
    readonly STENCIL_REF: number;
    readonly STENCIL_TEST: number;
    readonly STENCIL_VALUE_MASK: number;
    readonly STENCIL_WRITEMASK: number;
    readonly STREAM_DRAW: number;
    readonly SUBPIXEL_BITS: number;
    readonly TEXTURE0: number;
    readonly TEXTURE1: number;
    readonly TEXTURE10: number;
    readonly TEXTURE11: number;
    readonly TEXTURE12: number;
    readonly TEXTURE13: number;
    readonly TEXTURE14: number;
    readonly TEXTURE15: number;
    readonly TEXTURE16: number;
    readonly TEXTURE17: number;
    readonly TEXTURE18: number;
    readonly TEXTURE19: number;
    readonly TEXTURE2: number;
    readonly TEXTURE20: number;
    readonly TEXTURE21: number;
    readonly TEXTURE22: number;
    readonly TEXTURE23: number;
    readonly TEXTURE24: number;
    readonly TEXTURE25: number;
    readonly TEXTURE26: number;
    readonly TEXTURE27: number;
    readonly TEXTURE28: number;
    readonly TEXTURE29: number;
    readonly TEXTURE3: number;
    readonly TEXTURE30: number;
    readonly TEXTURE31: number;
    readonly TEXTURE4: number;
    readonly TEXTURE5: number;
    readonly TEXTURE6: number;
    readonly TEXTURE7: number;
    readonly TEXTURE8: number;
    readonly TEXTURE9: number;
    readonly TEXTURE_2D: number;
    readonly TEXTURE_BINDING_2D: number;
    readonly TEXTURE_BINDING_CUBE_MAP: number;
    readonly TEXTURE_CUBE_MAP: number;
    readonly TEXTURE_CUBE_MAP_NEGATIVE_X: number;
    readonly TEXTURE_CUBE_MAP_NEGATIVE_Y: number;
    readonly TEXTURE_CUBE_MAP_NEGATIVE_Z: number;
    readonly TEXTURE_CUBE_MAP_POSITIVE_X: number;
    readonly TEXTURE_CUBE_MAP_POSITIVE_Y: number;
    readonly TEXTURE_CUBE_MAP_POSITIVE_Z: number;
    readonly TEXTURE_MAG_FILTER: number;
    readonly TEXTURE_MAX_ANISOTROPY_EXT: number;
    readonly TEXTURE_MIN_FILTER: number;
    readonly TEXTURE_WRAP_S: number;
    readonly TEXTURE_WRAP_T: number;
    readonly TRIANGLES: number;
    readonly TRIANGLE_FAN: number;
    readonly TRIANGLE_STRIP: number;
    readonly UNPACK_ALIGNMENT: number;
    readonly UNPACK_COLORSPACE_CONVERSION_WEBGL: number;
    readonly UNPACK_FLIP_Y_WEBGL: number;
    readonly UNPACK_PREMULTIPLY_ALPHA_WEBGL: number;
    readonly UNSIGNED_BYTE: number;
    readonly UNSIGNED_INT: number;
    readonly UNSIGNED_SHORT: number;
    readonly UNSIGNED_SHORT_4_4_4_4: number;
    readonly UNSIGNED_SHORT_5_5_5_1: number;
    readonly UNSIGNED_SHORT_5_6_5: number;
    readonly VALIDATE_STATUS: number;
    readonly VENDOR: number;
    readonly VERSION: number;
    readonly VERTEX_ATTRIB_ARRAY_BUFFER_BINDING: number;
    readonly VERTEX_ATTRIB_ARRAY_ENABLED: number;
    readonly VERTEX_ATTRIB_ARRAY_NORMALIZED: number;
    readonly VERTEX_ATTRIB_ARRAY_POINTER: number;
    readonly VERTEX_ATTRIB_ARRAY_SIZE: number;
    readonly VERTEX_ATTRIB_ARRAY_STRIDE: number;
    readonly VERTEX_ATTRIB_ARRAY_TYPE: number;
    readonly VERTEX_SHADER: number;
    readonly VIEWPORT: number;
    readonly ZERO: number;
}
