"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var image_source_1 = require("tns-core-modules/image-source");
var TNSWebGLExtensions_1 = require("./TNSWebGLExtensions");
var TNSImageAsset_1 = require("./TNSImageAsset");
__export(require("./TNSWebGLExtensions"));
var TNSWebGLRenderingContext = (function (_super) {
    __extends(TNSWebGLRenderingContext, _super);
    function TNSWebGLRenderingContext(context) {
        var _this = _super.call(this) || this;
        _this.context = context;
        return _this;
    }
    TNSWebGLRenderingContext.prototype.getJSArray = function (value) {
        var count = value.count;
        var array = [];
        for (var i = 0; i < count; i++) {
            array.push(value.objectAtIndex(i));
        }
        return array;
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "native", {
        get: function () {
            return this.context;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferHeight", {
        get: function () {
            return this.context.drawingBufferHeight;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "drawingBufferWidth", {
        get: function () {
            return this.context.drawingBufferWidth;
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'error') {
            console.log(message, this.getError());
        }
    };
    TNSWebGLRenderingContext.prototype._checkArgs = function (message, args) {
        if (!TNSWebGLRenderingContext.isDebug) {
            return;
        }
        if (TNSWebGLRenderingContext.filter === 'both' || TNSWebGLRenderingContext.filter === 'args') {
            console.log('\/**** ', message, ' ****\/');
            console.dir(args);
            console.log('\/**** ', message, ' ****\/');
        }
    };
    TNSWebGLRenderingContext.prototype.activeTexture = function (texture) {
        this._glCheckError('activeTexture');
        this._checkArgs('activeTexture', arguments);
        this.context.activeTextureWithTexture(texture);
    };
    TNSWebGLRenderingContext.prototype.attachShader = function (program, shader) {
        var value = program ? program.native : 0;
        var value2 = shader ? shader.native : 0;
        this._glCheckError('attachShader');
        this._checkArgs('attachShader', arguments);
        this.context.attachShaderWithProgramShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.bindAttribLocation = function (program, index, name) {
        this._glCheckError('bindAttribLocation');
        this._checkArgs('bindAttribLocation', arguments);
        var value = program ? program.native : 0;
        this.context.bindAttribLocationWithProgramIndexName(value, index, name);
    };
    TNSWebGLRenderingContext.prototype.bindBuffer = function (target, buffer) {
        this._glCheckError('bindBuffer');
        this._checkArgs('bindBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        this.context.bindBufferWithTargetBuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindFramebuffer = function (target, framebuffer) {
        this._glCheckError('bindFramebuffer');
        this._checkArgs('bindFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : 0;
        this.context.bindFramebufferWithTargetFramebuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindRenderbuffer = function (target, renderbuffer) {
        this._glCheckError('bindRenderbuffer');
        this._checkArgs('bindRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        this.context.bindRenderbufferWithTargetRenderbuffer(target, value);
    };
    TNSWebGLRenderingContext.prototype.bindTexture = function (target, texture) {
        this._glCheckError('bindTexture');
        this._checkArgs('bindTexture', arguments);
        var value = texture ? texture.native : 0;
        this.context.bindTextureWithTargetTexture(target, value);
    };
    TNSWebGLRenderingContext.prototype.blendColor = function (red, green, blue, alpha) {
        this._glCheckError('blendColor');
        this._checkArgs('blendColor', arguments);
        this.context.blendColorWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquationSeparate = function (modeRGB, modeAlpha) {
        this._glCheckError('blendEquationSeparate');
        this._checkArgs('blendEquationSeparate', arguments);
        this.context.blendEquationSeparateWithModeRGBModeAlpha(modeRGB, modeAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendEquation = function (mode) {
        this._glCheckError('blendEquation');
        this._checkArgs('blendEquation', arguments);
        this.context.blendEquationWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.blendFuncSeparate = function (srcRGB, dstRGB, srcAlpha, dstAlpha) {
        if (srcRGB === void 0) { srcRGB = this.ONE; }
        if (dstRGB === void 0) { dstRGB = this.ZERO; }
        if (srcAlpha === void 0) { srcAlpha = this.ONE; }
        if (dstAlpha === void 0) { dstAlpha = this.ZERO; }
        this._glCheckError('blendFuncSeparate');
        this._checkArgs('blendFuncSeparate', arguments);
        this.context.blendFuncSeparateWithSrcRGBDstRGBSrcAlphaDstAlpha(srcRGB, dstRGB, srcAlpha, dstAlpha);
    };
    TNSWebGLRenderingContext.prototype.blendFunc = function (sfactor, dfactor) {
        if (sfactor === void 0) { sfactor = this.ONE; }
        if (dfactor === void 0) { dfactor = this.ZERO; }
        this._glCheckError('blendFunc');
        this._checkArgs('blendFunc', arguments);
        this.context.blendFuncWithSfactorDfactor(sfactor, dfactor);
    };
    TNSWebGLRenderingContext.prototype.bufferData = function (target, srcData, usage) {
        this._glCheckError('bufferData');
        this._checkArgs('bufferData', arguments);
        if (typeof srcData === 'number') {
            this.context.bufferDataWithTargetSizeUsage(target, srcData, usage);
        }
        else if (srcData instanceof ArrayBuffer) {
            this.context.bufferDataWithTargetByteArrayUsage(target, new Uint8Array(srcData.slice(0)), usage);
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Float32Array || srcData instanceof Float64Array) {
                this.context.bufferDataWithTargetFloatArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferDataWithTargetIntArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferDataWithTargetShortArrayUsage(target, srcData, usage);
            }
            else if (srcData instanceof Uint8Array) {
                this.context.bufferDataWithTargetByteArrayUsage(target, srcData, usage);
            }
        }
        else {
            this.context.bufferDataWithTargetSrcDataUsage(target, srcData, usage);
        }
    };
    TNSWebGLRenderingContext.prototype.bufferSubData = function (target, offset, srcData) {
        this._glCheckError('bufferSubData');
        this._checkArgs('bufferSubData', arguments);
        if (srcData instanceof ArrayBuffer) {
            this.context.bufferSubDataWithTargetOffsetByteArray(target, offset, new Uint8Array(srcData.slice(0)));
        }
        else if (srcData && srcData.buffer instanceof ArrayBuffer) {
            if (srcData instanceof Float32Array || srcData instanceof Float64Array) {
                this.context.bufferSubDataWithTargetOffsetFloatArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint32Array || srcData instanceof Int32Array) {
                this.context.bufferSubDataWithTargetOffsetIntArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint16Array || srcData instanceof Int16Array) {
                this.context.bufferSubDataWithTargetOffsetShortArray(target, offset, srcData);
            }
            else if (srcData instanceof Uint8Array) {
                this.context.bufferSubDataWithTargetOffsetByteArray(target, offset, srcData);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.checkFramebufferStatus = function (target) {
        this._glCheckError('checkFramebufferStatus');
        this._checkArgs('checkFramebufferStatus', arguments);
        return this.context.checkFramebufferStatusWithTarget(target);
    };
    TNSWebGLRenderingContext.prototype.clearColor = function (red, green, blue, alpha) {
        this._glCheckError('clearColor');
        this._checkArgs('clearColor', arguments);
        this.context.clearColorWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.clearDepth = function (depth) {
        this._glCheckError('clearDepth');
        this._checkArgs('clearDepth', arguments);
        this.context.clearDepthWithDepth(depth);
    };
    TNSWebGLRenderingContext.prototype.clearStencil = function (stencil) {
        this._glCheckError('clearStencil');
        this._checkArgs('clearStencil', arguments);
        this.context.clearStencilWithStencil(stencil);
    };
    TNSWebGLRenderingContext.prototype.clear = function (mask) {
        this._glCheckError('clear');
        this._checkArgs('clear', arguments);
        this.context.clearWithMask(mask);
        this._glCheckError('after clear');
    };
    TNSWebGLRenderingContext.prototype.colorMask = function (red, green, blue, alpha) {
        this._glCheckError('colorMask');
        this._checkArgs('colorMask', arguments);
        this.context.colorMaskWithRedGreenBlueAlpha(red, green, blue, alpha);
    };
    TNSWebGLRenderingContext.prototype.commit = function () {
        this.context.commit();
    };
    TNSWebGLRenderingContext.prototype.compileShader = function (shader) {
        this._glCheckError('compileShader');
        this._checkArgs('compileShader', arguments);
        var value = shader ? shader.native : 0;
        this.context.compileShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.compressedTexImage2D = function (target, level, internalformat, width, height, border, pixels) {
        this._glCheckError('compressedTexImage2D');
        this._checkArgs('compressedTexImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderFloatArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderIntArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderShortArray(target, level, internalformat, width, height, border, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderByteArray(target, level, internalformat, width, height, border, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderByteArray(target, level, internalformat, width, height, border, new Uint8Array(pixels.slice(0)));
        }
        else {
            this.context.compressedTexImage2DWithTargetLevelInternalformatWidthHeightBorderPixels(target, level, internalformat, width, height, border, pixels);
        }
    };
    TNSWebGLRenderingContext.prototype.compressedTexSubImage2D = function (target, level, xoffset, yoffset, width, height, format, pixels) {
        this._glCheckError('compressedTexSubImage2D');
        this._checkArgs('compressedTexSubImage2D', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatFloatArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatIntArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatShortArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatByteArray(target, level, xoffset, yoffset, width, height, format, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.compressedTexSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatByteArray(target, level, xoffset, yoffset, width, height, format, new Uint8Array(pixels.slice(0)));
        }
    };
    TNSWebGLRenderingContext.prototype.copyTexImage2D = function (target, level, internalformat, x, y, width, height, border) {
        this._glCheckError('copyTexImage2D');
        this._checkArgs('copyTexImage2D', arguments);
        this.context.copyTexImage2DWithTargetLevelInternalformatXYWidthHeightBorder(target, level, internalformat, x, y, width, height, border);
    };
    TNSWebGLRenderingContext.prototype.copyTexSubImage2D = function (target, level, xoffset, yoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage2D');
        this._checkArgs('copyTexSubImage2D', arguments);
        this.context.copyTexSubImage2DWithTargetLevelXoffsetYoffsetXYWidthHeight(target, level, xoffset, yoffset, x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.createBuffer = function () {
        this._glCheckError('createBuffer');
        this._checkArgs('createBuffer', arguments);
        var id = this.context.createBuffer();
        return new canvas_plugin_common_1.WebGLBuffer(id);
    };
    TNSWebGLRenderingContext.prototype.createFramebuffer = function () {
        this._glCheckError('createFramebuffer');
        this._checkArgs('createFramebuffer', arguments);
        return new canvas_plugin_common_1.WebGLFramebuffer(this.context.createFramebuffer());
    };
    TNSWebGLRenderingContext.prototype.createProgram = function () {
        this._glCheckError('createProgram');
        this._checkArgs('createProgram', arguments);
        return new canvas_plugin_common_1.WebGLProgram(this.context.createProgram());
    };
    TNSWebGLRenderingContext.prototype.createRenderbuffer = function () {
        this._glCheckError('bindBuffer');
        this._checkArgs('bindBuffer', arguments);
        return new canvas_plugin_common_1.WebGLRenderbuffer(this.context.createRenderbuffer());
    };
    TNSWebGLRenderingContext.prototype.createShader = function (type) {
        this._glCheckError('createRenderbuffer');
        this._checkArgs('createRenderbuffer', arguments);
        return new canvas_plugin_common_1.WebGLShader(this.context.createShaderWithType(type));
    };
    TNSWebGLRenderingContext.prototype.createTexture = function () {
        this._glCheckError('createTexture');
        this._checkArgs('createTexture', arguments);
        var id = this.context.createTexture();
        return new canvas_plugin_common_1.WebGLTexture(id);
    };
    TNSWebGLRenderingContext.prototype.cullFace = function (mode) {
        this._glCheckError('cullFace');
        this._checkArgs('cullFace', arguments);
        this.context.cullFaceWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.deleteBuffer = function (buffer) {
        this._glCheckError('deleteBuffer');
        this._checkArgs('deleteBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        this.context.deleteBufferWithBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteFramebuffer = function (frameBuffer) {
        this._glCheckError('deleteFramebuffer');
        this._checkArgs('deleteFramebuffer', arguments);
        var value = frameBuffer ? frameBuffer.native : 0;
        this.context.deleteFramebufferWithFrameBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteProgram = function (program) {
        this._glCheckError('deleteProgram');
        this._checkArgs('deleteProgram', arguments);
        var value = program ? program.native : 0;
        this.context.deleteProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.deleteRenderbuffer = function (renderBuffer) {
        this._glCheckError('deleteRenderbuffer');
        this._checkArgs('deleteRenderbuffer', arguments);
        var value = renderBuffer ? renderBuffer.native : 0;
        this.context.deleteRenderbufferWithRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.deleteShader = function (shader) {
        this._glCheckError('deleteShader');
        this._checkArgs('deleteShader', arguments);
        var value = shader ? shader.native : 0;
        this.context.deleteShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.deleteTexture = function (texture) {
        this._glCheckError('deleteTexture');
        this._checkArgs('deleteTexture', arguments);
        var value = texture ? texture.native : 0;
        this.context.deleteTextureWithTexture(value);
    };
    TNSWebGLRenderingContext.prototype.depthFunc = function (func) {
        this._glCheckError('depthFunc');
        this._checkArgs('depthFunc', arguments);
        this.context.depthFuncWithFn(func);
    };
    TNSWebGLRenderingContext.prototype.depthMask = function (flag) {
        this._glCheckError('depthMask');
        this._checkArgs('depthMask', arguments);
        this.context.depthMaskWithFlag(flag);
    };
    TNSWebGLRenderingContext.prototype.depthRange = function (zNear, zFar) {
        this._glCheckError('depthRange');
        this._checkArgs('depthRange', arguments);
        this.context.depthRangeWithZNearZFar(zNear, zFar);
    };
    TNSWebGLRenderingContext.prototype.detachShader = function (program, shader) {
        this._glCheckError('detachShader');
        this._checkArgs('detachShader', arguments);
        var value = program ? program.native : 0;
        var value2 = shader ? shader.native : 0;
        this.context.detachShaderWithProgramShader(value, value2);
    };
    TNSWebGLRenderingContext.prototype.disableVertexAttribArray = function (index) {
        this._checkArgs('disableVertexAttribArray', arguments);
        this._glCheckError('disableVertexAttribArray');
        this.context.disableVertexAttribArrayWithIndex(index);
    };
    TNSWebGLRenderingContext.prototype.disable = function (cap) {
        this._glCheckError('disable');
        this._checkArgs('disable', arguments);
        this.context.disableWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.drawArrays = function (mode, first, count) {
        this._glCheckError('drawArrays');
        this._checkArgs('drawArrays', arguments);
        this.context.drawArraysWithModeFirstCount(mode, first, count);
    };
    TNSWebGLRenderingContext.prototype.drawElements = function (mode, count, type, offset) {
        this._glCheckError('drawElements');
        this._checkArgs('drawElements', arguments);
        this.context.drawElementsWithModeCountTypeOffset(mode, count, type, offset);
    };
    TNSWebGLRenderingContext.prototype.enableVertexAttribArray = function (index) {
        this._glCheckError('enableVertexAttribArray');
        this._checkArgs('enableVertexAttribArray', arguments);
        this.context.enableVertexAttribArrayWithIndex(index);
    };
    TNSWebGLRenderingContext.prototype.enable = function (cap) {
        this._glCheckError('enable');
        this._checkArgs('enable', arguments);
        this.context.enableWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.finish = function () {
        this._glCheckError('finish');
        this._checkArgs('finish', arguments);
        this.context.finish();
    };
    TNSWebGLRenderingContext.prototype.flush = function () {
        this._glCheckError('flush');
        this._checkArgs('flush', arguments);
        this.context.flush();
    };
    TNSWebGLRenderingContext.prototype.framebufferRenderbuffer = function (target, attachment, renderbuffertarget, renderbuffer) {
        this._glCheckError('framebufferRenderbuffer');
        this._checkArgs('framebufferRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        this.context.framebufferRenderbufferWithTargetAttachmentRenderbuffertargetRenderbuffer(target, attachment, renderbuffertarget, value);
    };
    TNSWebGLRenderingContext.prototype.framebufferTexture2D = function (target, attachment, textarget, texture, level) {
        this._glCheckError('framebufferTexture2D');
        this._checkArgs('framebufferTexture2D', arguments);
        var value = texture ? texture.native : 0;
        this.context.framebufferTexture2DWithTargetAttachmentTextargetTextureLevel(target, attachment, textarget, value, level);
    };
    TNSWebGLRenderingContext.prototype.frontFace = function (mode) {
        this._glCheckError('frontFace');
        this._checkArgs('frontFace', arguments);
        this.context.frontFaceWithMode(mode);
    };
    TNSWebGLRenderingContext.prototype.generateMipmap = function (target) {
        this._glCheckError('generateMipmap');
        this._checkArgs('generateMipmap', arguments);
        this.context.generateMipmapWithTarget(target);
    };
    TNSWebGLRenderingContext.prototype.getActiveAttrib = function (program, index) {
        this._glCheckError('getActiveAttrib');
        this._checkArgs('getActiveAttrib', arguments);
        var value = program ? program.native : 0;
        var attrib = this.context.getActiveAttribWithProgramIndex(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(attrib.name, attrib.size, attrib.type);
    };
    TNSWebGLRenderingContext.prototype.getActiveUniform = function (program, index) {
        this._glCheckError('getActiveUniform');
        this._checkArgs('getActiveUniform', arguments);
        var value = program ? program.native : 0;
        var uniform = this.context.getActiveUniformWithProgramIndex(value, index);
        return new canvas_plugin_common_1.WebGLActiveInfo(uniform.name, uniform.size, uniform.type);
    };
    TNSWebGLRenderingContext.prototype.getAttachedShaders = function (program) {
        this._glCheckError('getAttachedShaders');
        this._checkArgs('getAttachedShaders', arguments);
        var value = program ? program.native : 0;
        var shaders = this.context.getAttachedShadersWithProgram(value);
        var length = shaders.count;
        var attachedShaders = [];
        for (var i = 0; i < length; i++) {
            attachedShaders.push(new canvas_plugin_common_1.WebGLShader(shaders.objectAtIndex(i)));
        }
        return attachedShaders;
    };
    TNSWebGLRenderingContext.prototype.getAttribLocation = function (program, name) {
        this._glCheckError('getAttribLocation');
        this._checkArgs('getAttribLocation', arguments);
        var value = program ? program.native : 0;
        return this.context.getAttribLocationWithProgramName(value, name);
    };
    TNSWebGLRenderingContext.prototype.getBufferParameter = function (target, pname) {
        this._glCheckError('getBufferParameter');
        this._checkArgs('getBufferParameter', arguments);
        return this.context.getBufferParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getContextAttributes = function () {
        this._glCheckError('getContextAttributes');
        this._checkArgs('getContextAttributes', arguments);
        var attributes = this.context.getContextAttributes();
        var keys = attributes.allKeys;
        var length = keys.count;
        var contextAttributes = {};
        for (var i = 0; i < length; i++) {
            var key = keys.objectAtIndex(i);
            contextAttributes[key] = attributes.objectForKey(key);
        }
        return contextAttributes;
    };
    TNSWebGLRenderingContext.prototype.getError = function () {
        return this.context.getError();
    };
    TNSWebGLRenderingContext.prototype.getExtension = function (name) {
        this._checkArgs('activattachShadereTexture', arguments);
        this._glCheckError('activattachShadereTexture');
        var ext = this.context.getExtensionWithName(name);
        if (ext instanceof Canvas_EXT_blend_minmax) {
            return new TNSWebGLExtensions_1.EXT_blend_minmax(ext);
        }
        else if (ext instanceof Canvas_EXT_color_buffer_float) {
            return new TNSWebGLExtensions_1.EXT_color_buffer_float(ext);
        }
        else if (ext instanceof Canvas_EXT_color_buffer_half_float) {
            return new TNSWebGLExtensions_1.EXT_color_buffer_half_float(ext);
        }
        else if (ext instanceof Canvas_EXT_sRGB) {
            return new TNSWebGLExtensions_1.EXT_sRGB(ext);
        }
        else if (ext instanceof Canvas_EXT_shader_texture_lod) {
            return new TNSWebGLExtensions_1.EXT_shader_texture_lod(ext);
        }
        else if (ext instanceof Canvas_EXT_texture_filter_anisotropic) {
            return new TNSWebGLExtensions_1.EXT_texture_filter_anisotropic(ext);
        }
        else if (ext instanceof Canvas_OES_element_index_uint) {
            return new TNSWebGLExtensions_1.OES_element_index_uint(ext);
        }
        else if (ext instanceof Canvas_OES_fbo_render_mipmap) {
            return new TNSWebGLExtensions_1.OES_fbo_render_mipmap(ext);
        }
        else if (ext instanceof Canvas_OES_standard_derivatives) {
            return new TNSWebGLExtensions_1.OES_standard_derivatives(ext);
        }
        else if (ext instanceof Canvas_OES_texture_float) {
            return new TNSWebGLExtensions_1.OES_texture_float(ext);
        }
        else if (ext instanceof Canvas_OES_texture_float_linear) {
            return new TNSWebGLExtensions_1.OES_texture_float_linear(ext);
        }
        else if (ext instanceof Canvas_OES_texture_half_float) {
            return new TNSWebGLExtensions_1.OES_texture_half_float(ext);
        }
        else if (ext instanceof Canvas_OES_texture_half_float_linear) {
            return new TNSWebGLExtensions_1.OES_texture_half_float_linear(ext);
        }
        else if (ext instanceof Canvas_OES_vertex_array_object) {
            return new TNSWebGLExtensions_1.OES_vertex_array_object(ext);
        }
        else if (ext instanceof Canvas_WEBGL_color_buffer_float) {
            return new TNSWebGLExtensions_1.WEBGL_color_buffer_float(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_etc) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_etc1) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_etc1(ext);
        }
        else if (ext instanceof Canvas_WEBGL_compressed_texture_pvrtc) {
            return new TNSWebGLExtensions_1.WEBGL_compressed_texture_pvrtc(ext);
        }
        else if (ext instanceof Canvas_WEBGL_depth_texture) {
            return new TNSWebGLExtensions_1.WEBGL_depth_texture(ext);
        }
        else if (ext instanceof Canvas_WEBGL_lose_context) {
            return new TNSWebGLExtensions_1.WEBGL_lose_context(ext);
        }
        return null;
    };
    TNSWebGLRenderingContext.prototype.getFramebufferAttachmentParameter = function (target, attachment, pname) {
        this._glCheckError('getFramebufferAttachmentParameter');
        this._checkArgs('getFramebufferAttachmentParameter', arguments);
        var param = this.context.getFramebufferAttachmentParameterWithTargetAttachmentPname(target, attachment, pname);
        if (param.isRenderbuffer) {
            return new canvas_plugin_common_1.WebGLRenderbuffer(param.value);
        }
        else if (param.isTexture) {
            return new canvas_plugin_common_1.WebGLTexture(param.value);
        }
        return param.value;
    };
    TNSWebGLRenderingContext.prototype.getParameter = function (pname) {
        this._glCheckError('getParameter');
        this._checkArgs('getParameter', arguments);
        var value = this.context.getParameterWithPname(pname);
        switch (pname) {
            case this.COLOR_WRITEMASK:
            case this.COLOR_CLEAR_VALUE:
            case this.BLEND_COLOR:
            case this.ALIASED_LINE_WIDTH_RANGE:
            case this.ALIASED_POINT_SIZE_RANGE:
            case this.DEPTH_RANGE:
                if (value instanceof NSArray) {
                    var count = value.count;
                    var array = [];
                    for (var i = 0; i < count; i++) {
                        array.push(value.objectAtIndex(i));
                    }
                    return array;
                }
                return value;
            case this.ARRAY_BUFFER_BINDING:
            case this.ELEMENT_ARRAY_BUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLBuffer(value);
            case this.CURRENT_PROGRAM:
                return new canvas_plugin_common_1.WebGLProgram(value);
            case this.COMPRESSED_TEXTURE_FORMATS:
                var size = value.count;
                var result = [];
                for (var i = 0; i < size; i++) {
                    result.push(value.objectAtIndex(i));
                }
                return new Uint32Array(result);
            case this.RENDERBUFFER_BINDING:
                return new canvas_plugin_common_1.WebGLRenderbuffer(value);
            case this.FRAMEBUFFER_BINDING:
                if (value) {
                    return new canvas_plugin_common_1.WebGLFramebuffer(value);
                }
                return null;
            case this.VIEWPORT:
            case this.SCISSOR_BOX:
            case this.MAX_VIEWPORT_DIMS:
                var len = value.count;
                var arr = [];
                for (var i = 0; i < len; i++) {
                    arr.push(value.objectAtIndex(i));
                }
                return new Int32Array(arr);
            case this.TEXTURE_BINDING_CUBE_MAP:
            case this.TEXTURE_BINDING_2D:
                if (value) {
                    return new canvas_plugin_common_1.WebGLTexture(value);
                }
                return null;
            default:
                return value;
        }
    };
    TNSWebGLRenderingContext.prototype.getProgramInfoLog = function (program) {
        this._glCheckError('getProgramInfoLog');
        this._checkArgs('getProgramInfoLog', arguments);
        var value = program ? program.native : 0;
        return this.context.getProgramInfoLogWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.getProgramParameter = function (program, pname) {
        this._glCheckError('getProgramParameter');
        this._checkArgs('getProgramParameter', arguments);
        var value = program ? program.native : 0;
        return this.context.getProgramParameterWithProgramPname(value, pname);
    };
    TNSWebGLRenderingContext.prototype.getRenderbufferParameter = function (target, pname) {
        this._glCheckError('getRenderbufferParameter');
        this._checkArgs('getRenderbufferParameter', arguments);
        return this.context.getBufferParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderInfoLog = function (shader) {
        this._glCheckError('getShaderInfoLog');
        this._checkArgs('getShaderInfoLog', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderInfoLogWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.getShaderParameter = function (shader, pname) {
        this._glCheckError('getShaderParameter');
        this._checkArgs('getShaderParameter', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderParameterWithShaderPname(value, pname);
    };
    TNSWebGLRenderingContext.prototype.getShaderPrecisionFormat = function (shaderType, precisionType) {
        this._glCheckError('getShaderPrecisionFormat');
        this._checkArgs('getShaderPrecisionFormat', arguments);
        var precision = this.context.getShaderPrecisionFormatWithShaderTypePrecisionType(shaderType, precisionType);
        return new canvas_plugin_common_1.WebGLShaderPrecisionFormat(precision.rangeMin, precision.rangeMax, precision.precision);
    };
    TNSWebGLRenderingContext.prototype.getShaderSource = function (shader) {
        this._glCheckError('getShaderSource');
        this._checkArgs('getShaderSource', arguments);
        var value = shader ? shader.native : 0;
        return this.context.getShaderSourceWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.getSupportedExtensions = function () {
        this._glCheckError('getSupportedExtensions');
        this._checkArgs('getSupportedExtensions', arguments);
        var extensions = this.context.getSupportedExtensions();
        var array = [];
        var length = extensions.count;
        for (var i = 0; i < length; i++) {
            array.push(extensions.objectAtIndex(i));
        }
        return array;
    };
    TNSWebGLRenderingContext.prototype.getTexParameter = function (target, pname) {
        this._glCheckError('getTexParameter');
        this._checkArgs('getTexParameter', arguments);
        return this.context.getTexParameterWithTargetPname(target, pname);
    };
    TNSWebGLRenderingContext.prototype.getUniformLocation = function (program, name) {
        this._glCheckError('getUniformLocation');
        this._checkArgs('getUniformLocation', arguments);
        var value = program ? program.native : 0;
        return new canvas_plugin_common_1.WebGLUniformLocation(this.context.getUniformLocationWithProgramName(value, name));
    };
    TNSWebGLRenderingContext.prototype.getUniform = function (program, location) {
        this._glCheckError('getUniform');
        this._checkArgs('getUniform', arguments);
        var value = program ? program.native : 0;
        var value2 = location ? location.native : 0;
        var result = this.context.getUniformWithProgramLocation(value, value2);
        if (result instanceof NSArray) {
            var array = [];
            var length = result.count;
            for (var i = 0; i < length; i++) {
                array.push(result.objectAtIndex(i));
            }
            return array;
        }
        return result;
    };
    TNSWebGLRenderingContext.prototype.getVertexAttribOffset = function (index, pname) {
        this._glCheckError('getVertexAttribOffset');
        this._checkArgs('getVertexAttribOffset', arguments);
        return this.context.getVertexAttribOffsetWithIndexPname(index, pname);
    };
    TNSWebGLRenderingContext.prototype.getVertexAttrib = function (index, pname) {
        this._glCheckError('getVertexAttrib');
        this._checkArgs('getVertexAttrib', arguments);
        var value = this.context.getVertexAttribWithIndexPname(index, pname);
        if (pname === this.CURRENT_VERTEX_ATTRIB && value instanceof NSArray) {
            var count = value.count;
            var array = [];
            for (var i = 0; i < count; i++) {
                array.push(value.objectAtIndex(i));
            }
            return array;
        }
        return value;
    };
    TNSWebGLRenderingContext.prototype.hint = function (target, mode) {
        this._glCheckError('hint');
        this._checkArgs('hint', arguments);
        this.context.hintWithTargetMode(target, mode);
    };
    TNSWebGLRenderingContext.prototype.isBuffer = function (buffer) {
        this._glCheckError('isBuffer');
        this._checkArgs('isBuffer', arguments);
        var value = buffer ? buffer.native : 0;
        return this.context.isBufferWithBuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isContextLost = function () {
        this._glCheckError('isContextLost');
        this._checkArgs('isContextLost', arguments);
        return false;
    };
    TNSWebGLRenderingContext.prototype.isEnabled = function (cap) {
        this._glCheckError('isEnabled');
        this._checkArgs('isEnabled', arguments);
        return this.context.isEnabledWithCap(cap);
    };
    TNSWebGLRenderingContext.prototype.isFramebuffer = function (framebuffer) {
        this._glCheckError('isFramebuffer');
        this._checkArgs('isFramebuffer', arguments);
        var value = framebuffer ? framebuffer.native : 0;
        return this.context.isFramebufferWithFramebuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isProgram = function (program) {
        this._glCheckError('isProgram');
        this._checkArgs('isProgram', arguments);
        var value = program ? program.native : 0;
        return this.context.isProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.isRenderbuffer = function (renderbuffer) {
        this._glCheckError('isRenderbuffer');
        this._checkArgs('isRenderbuffer', arguments);
        var value = renderbuffer ? renderbuffer.native : 0;
        return this.context.isRenderbufferWithRenderbuffer(value);
    };
    TNSWebGLRenderingContext.prototype.isShader = function (shader) {
        this._glCheckError('isShader');
        this._checkArgs('isShader', arguments);
        var value = shader ? shader.native : 0;
        return this.context.isShaderWithShader(value);
    };
    TNSWebGLRenderingContext.prototype.isTexture = function (texture) {
        this._glCheckError('isTexture');
        this._checkArgs('isTexture', arguments);
        var value = texture ? texture.native : 0;
        return this.context.isTextureWithTexture(value);
    };
    TNSWebGLRenderingContext.prototype.lineWidth = function (width) {
        this._glCheckError('lineWidth');
        this._checkArgs('lineWidth', arguments);
        this.context.lineWidthWithWidth(width);
    };
    TNSWebGLRenderingContext.prototype.linkProgram = function (program) {
        this._glCheckError('linkProgram');
        this._checkArgs('linkProgram', arguments);
        var value = program ? program.native : 0;
        this.context.linkProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.pixelStorei = function (pname, param) {
        this._glCheckError('pixelStorei');
        this._checkArgs('pixelStorei', arguments);
        this.context.pixelStoreiWithPnameParam(pname, param);
    };
    TNSWebGLRenderingContext.prototype.polygonOffset = function (factor, units) {
        this._glCheckError('polygonOffset');
        this._checkArgs('polygonOffset', arguments);
        this.context.polygonOffsetWithFactorUnits(factor, units);
    };
    TNSWebGLRenderingContext.prototype.readPixels = function (x, y, width, height, format, type, pixels) {
        this._glCheckError('readPixels');
        this._checkArgs('readPixels', arguments);
        if (pixels && pixels.buffer instanceof ArrayBuffer) {
            if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeFloatArray(x, y, width, height, format, type, pixels);
            }
            else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeShortArray(x, y, width, height, format, type, pixels);
            }
            else if (pixels instanceof Uint8Array) {
                this.context.readPixelsWithXYWidthHeightFormatTypeByteArray(x, y, width, height, format, type, pixels);
            }
        }
        else if (pixels instanceof ArrayBuffer) {
            this.context.readPixelsWithXYWidthHeightFormatTypeByteArray(x, y, width, height, format, type, new Uint8Array(pixels.slice(0)));
        }
    };
    TNSWebGLRenderingContext.prototype.renderbufferStorage = function (target, internalFormat, width, height) {
        this._glCheckError('renderbufferStorage');
        this._checkArgs('renderbufferStorage', arguments);
        if (internalFormat === this.DEPTH_STENCIL) {
            internalFormat = 35056;
        }
        this.context.renderbufferStorageWithTargetInternalFormatWidthHeight(target, internalFormat, width, height);
    };
    TNSWebGLRenderingContext.prototype.sampleCoverage = function (value, invert) {
        this._glCheckError('sampleCoverage');
        this._checkArgs('sampleCoverage', arguments);
        this.context.sampleCoverageWithValueInvert(value, invert);
    };
    TNSWebGLRenderingContext.prototype.scissor = function (x, y, width, height) {
        this._glCheckError('scissor');
        this._checkArgs('scissor', arguments);
        this.context.scissorWithXYWidthHeight(x, y, width, height);
    };
    TNSWebGLRenderingContext.prototype.shaderSource = function (shader, source) {
        this._glCheckError('shaderSource');
        this._checkArgs('shaderSource', arguments);
        var value = shader ? shader.native : 0;
        this.context.shaderSourceWithShaderSource(value, source);
    };
    TNSWebGLRenderingContext.prototype.stencilFuncSeparate = function (face, func, ref, mask) {
        this._glCheckError('stencilFuncSeparate');
        this._checkArgs('stencilFuncSeparate', arguments);
        this.context.stencilFuncSeparateWithFaceFnRefMask(face, func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilFunc = function (func, ref, mask) {
        this._glCheckError('stencilFunc');
        this._checkArgs('stencilFunc', arguments);
        this.context.stencilFuncWithFnRefMask(func, ref, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMaskSeparate = function (face, mask) {
        this._glCheckError('stencilMaskSeparate');
        this._checkArgs('stencilMaskSeparate', arguments);
        this.context.stencilMaskSeparateWithFaceMask(face, mask);
    };
    TNSWebGLRenderingContext.prototype.stencilMask = function (mask) {
        this._glCheckError('stencilMask');
        this._checkArgs('stencilMask', arguments);
        this.context.stencilMaskWithMask(mask);
    };
    TNSWebGLRenderingContext.prototype.stencilOpSeparate = function (face, fail, zfail, zpass) {
        this._glCheckError('stencilOpSeparate');
        this._checkArgs('stencilOpSeparate', arguments);
        this.context.stencilOpSeparateWithFaceFailZfailZpass(face, fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.stencilOp = function (fail, zfail, zpass) {
        this._glCheckError('stencilOp');
        this._checkArgs('stencilOp', arguments);
        this.context.stencilOpWithFailZfailZpass(fail, zfail, zpass);
    };
    TNSWebGLRenderingContext.prototype.texImage2D = function (target, level, internalformat, width, height, border, format, type, pixels) {
        this._glCheckError('texImage2D');
        this._checkArgs('texImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeFloatArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint32Array || pixels instanceof Int32Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeIntArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeShortArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
                else if (pixels instanceof Uint8Array) {
                    this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeByteArray(target, level, internalformat, width, height, border, format, type, pixels);
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypeByteArray(target, level, internalformat, width, height, border, format, type, new Uint8Array(pixels.slice(0)));
            }
            else {
                this.context.texImage2DWithTargetLevelInternalformatWidthHeightBorderFormatTypePixels(target, level, internalformat, width, height, border, format, type, pixels);
            }
        }
        else if (arguments.length === 6) {
            if (border instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypeAsset(target, level, internalformat, width, height, border.native);
            }
            else if (border instanceof image_source_1.ImageSource) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border.ios);
            }
            else if (border instanceof UIImage) {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border);
            }
            else if (border &&
                typeof border.tagName === 'string' &&
                border.tagName === 'IMG') {
                if (border._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypeAsset(target, level, internalformat, width, height, border._asset.native);
                }
                else if (border._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border._imageSource.ios);
                }
                else if (border._image instanceof UIImage) {
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, border._image);
                }
                else if (typeof border.src === 'string') {
                    var asset = image_source_1.fromFile(border.src);
                    this.context.texImage2DWithTargetLevelInternalformatFormatTypePixels(target, level, internalformat, width, height, asset.ios);
                }
            }
            else {
                this.context.texImage2DWithTargetLevelInternalformatFormatTypeNone(target, level, internalformat, width, height, border);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.texParameterf = function (target, pname, param) {
        this._glCheckError('texParameterf');
        this._checkArgs('texParameterf', arguments);
        this.context.texParameterfWithTargetPnameParam(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texParameteri = function (target, pname, param) {
        this._glCheckError('texParameteri');
        this._checkArgs('texParameteri', arguments);
        this.context.texParameteriWithTargetPnameParam(target, pname, param);
    };
    TNSWebGLRenderingContext.prototype.texSubImage2D = function (target, level, xoffset, yoffset, width, height, format, type, pixels) {
        this._glCheckError('texSubImage2D');
        this._checkArgs('texSubImage2D', arguments);
        if (arguments.length === 9) {
            if (pixels && pixels.buffer) {
                if (pixels instanceof Float32Array || pixels instanceof Float64Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeFloatArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
                else if (pixels instanceof Uint16Array || pixels instanceof Int16Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeShortArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
                else if (pixels instanceof Uint8Array) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeByteArray(target, level, xoffset, yoffset, width, height, format, type, pixels);
                }
            }
            else if (pixels instanceof ArrayBuffer) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypeByteArray(target, level, xoffset, yoffset, width, height, format, type, new Uint8Array(pixels.slice(0)));
            }
            else {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetWidthHeightFormatTypePixels(target, level, xoffset, yoffset, width, height, format, type, pixels);
            }
        }
        else if (arguments.length === 7) {
            if (format instanceof TNSImageAsset_1.TNSImageAsset) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeAsset(target, level, xoffset, yoffset, width, height, format.native);
            }
            else if (format instanceof UIImage) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format);
            }
            else if (format instanceof image_source_1.ImageSource) {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format.ios);
            }
            else if (format &&
                typeof format.tagName === 'string' &&
                format.tagName === 'IMG') {
                if (format._imageSource instanceof image_source_1.ImageSource) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format._imageSource.ios);
                }
                else if (format._image instanceof UIImage) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, format._image);
                }
                else if (format._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeAsset(target, level, xoffset, yoffset, width, height, format._asset.native);
                }
                else if (typeof format.src === 'string') {
                    var result = image_source_1.fromFile(format.src);
                    this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypePixels(target, level, xoffset, yoffset, width, height, result ? result.ios : null);
                }
            }
            else {
                this.context.texSubImage2DWithTargetLevelXoffsetYoffsetFormatTypeNone(target, level, xoffset, yoffset, width, height, format);
            }
        }
    };
    TNSWebGLRenderingContext.prototype.uniform1f = function (location, v0) {
        this._glCheckError('uniform1f');
        this._checkArgs('uniform1f', arguments);
        this.context.uniform1fWithLocationV0(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform1iv = function (location, value) {
        this._glCheckError('uniform1iv');
        this._checkArgs('uniform1iv', arguments);
        this.context.uniform1ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1fv = function (location, value) {
        this._glCheckError('uniform1fv');
        this._checkArgs('uniform1fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform1fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform1i = function (location, v0) {
        this._glCheckError('uniform1i');
        this._checkArgs('uniform1i', arguments);
        this.context.uniform1iWithLocationV0(location.native, v0);
    };
    TNSWebGLRenderingContext.prototype.uniform2f = function (location, v0, v1) {
        this._glCheckError('uniform2f');
        this._checkArgs('uniform2f', arguments);
        this.context.uniform2fWithLocationV0V1(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform2iv = function (location, value) {
        this._glCheckError('uniform2iv');
        this._checkArgs('activattachShadereTexture', arguments);
        this.context.uniform2ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2fv = function (location, value) {
        this._glCheckError('uniform2fv');
        this._checkArgs('uniform2fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform2fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform2i = function (location, v0, v1) {
        this._glCheckError('uniform2i');
        this._checkArgs('uniform2i', arguments);
        this.context.uniform2iWithLocationV0V1(location.native, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.uniform3f = function (location, v0, v1, v2) {
        this._glCheckError('uniform3f');
        this._checkArgs('uniform3f', arguments);
        this.context.uniform3fWithLocationV0V1V2(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform3iv = function (location, value) {
        this._glCheckError('uniform3iv');
        this._checkArgs('uniform3iv', arguments);
        this.context.uniform3ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3fv = function (location, value) {
        this._glCheckError('uniform3fv');
        this._checkArgs('uniform3fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform3fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform3i = function (location, v0, v1, v2) {
        this._glCheckError('uniform3i');
        this._checkArgs('uniform3i', arguments);
        this.context.uniform3iWithLocationV0V1V2(location.native, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.uniform4f = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4f');
        this._checkArgs('uniform4f', arguments);
        this.context.uniform4fWithLocationV0V1V2V3(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniform4iv = function (location, value) {
        this._glCheckError('uniform4iv');
        this._checkArgs('uniform4iv', arguments);
        this.context.uniform4ivWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4fv = function (location, value) {
        this._glCheckError('uniform4fv');
        this._checkArgs('uniform4fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniform4fvWithLocationValue(location.native, value);
    };
    TNSWebGLRenderingContext.prototype.uniform4i = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4i');
        this._checkArgs('uniform4i', arguments);
        this.context.uniform4iWithLocationV0V1V2V3(location.native, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix2fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix2fv');
        this._checkArgs('uniformMatrix2fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix2fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix3fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix3fv');
        this._checkArgs('uniformMatrix3fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix3fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.uniformMatrix4fv = function (location, transpose, value) {
        this._glCheckError('uniformMatrix4fv');
        this._checkArgs('uniformMatrix4fv', arguments);
        if (!(value instanceof Float32Array)) {
            value = new Float32Array(value);
        }
        this.context.uniformMatrix4fvWithLocationTransposeValue(location.native, transpose, value);
    };
    TNSWebGLRenderingContext.prototype.useProgram = function (program) {
        this._glCheckError('useProgram');
        this._checkArgs('useProgram', arguments);
        var value = program ? program.native : 0;
        this.context.useProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.validateProgram = function (program) {
        this._glCheckError('validateProgram');
        this._checkArgs('validateProgram', arguments);
        var value = program ? program.native : 0;
        this.context.validateProgramWithProgram(value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1f = function (index, v0) {
        this._glCheckError('vertexAttrib1f');
        this._checkArgs('vertexAttrib1f', arguments);
        this.context.vertexAttrib1fWithIndexV0(index, v0);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib1fv = function (index, value) {
        this._glCheckError('vertexAttrib1fv');
        this._checkArgs('vertexAttrib1fv', arguments);
        this.context.vertexAttrib1fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2f = function (index, v0, v1) {
        this._glCheckError('vertexAttrib2f');
        this._checkArgs('vertexAttrib2f', arguments);
        this.context.vertexAttrib2fWithIndexV0V1(index, v0, v1);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib2fv = function (index, value) {
        this._glCheckError('vertexAttrib2fv');
        this._checkArgs('vertexAttrib2fv', arguments);
        this.context.vertexAttrib2fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3f = function (index, v0, v1, v2) {
        this._glCheckError('vertexAttrib3f');
        this._checkArgs('vertexAttrib3f', arguments);
        this.context.vertexAttrib3fWithIndexV0V1V2(index, v0, v1, v2);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib3fv = function (index, value) {
        this._glCheckError('vertexAttrib3fv');
        this._checkArgs('vertexAttrib3fv', arguments);
        this.context.vertexAttrib3fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4f = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttrib4f');
        this._checkArgs('vertexAttrib4f', arguments);
        this.context.vertexAttrib4fWithIndexV0V1V2V3(index, v0, v1, v2, v3);
    };
    TNSWebGLRenderingContext.prototype.vertexAttrib4fv = function (index, value) {
        this._glCheckError('vertexAttrib4fv');
        this._checkArgs('vertexAttrib4fv', arguments);
        this.context.vertexAttrib4fvWithIndexValue(index, value);
    };
    TNSWebGLRenderingContext.prototype.vertexAttribPointer = function (index, size, type, normalized, stride, offset) {
        this._glCheckError('vertexAttribPointer');
        this._checkArgs('vertexAttribPointer', arguments);
        this.context.vertexAttribPointerWithIndexSizeTypeNormalizedStrideOffset(index, size, type, normalized, stride, offset);
    };
    TNSWebGLRenderingContext.prototype.viewport = function (x, y, width, height) {
        this._glCheckError('viewport');
        this._checkArgs('viewport', arguments);
        this.context.viewportWithXYWidthHeight(x, y, width, height);
    };
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_CONSTANT_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_CONSTANT_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONSTANT_ALPHA", {
        get: function () {
            return this.context.CONSTANT_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_CONSTANT_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_CONSTANT_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONSTANT_COLOR", {
        get: function () {
            return this.context.CONSTANT_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_ALPHA_SATURATE", {
        get: function () {
            return this.context.SRC_ALPHA_SATURATE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_DST_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_DST_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DST_COLOR", {
        get: function () {
            return this.context.DST_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_DST_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DST_ALPHA", {
        get: function () {
            return this.context.DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_SRC_COLOR", {
        get: function () {
            return this.context.ONE_MINUS_SRC_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_COLOR", {
        get: function () {
            return this.context.SRC_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRC_ALPHA", {
        get: function () {
            return this.context.SRC_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE_MINUS_SRC_ALPHA", {
        get: function () {
            return this.context.ONE_MINUS_SRC_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_ATTRIBUTES", {
        get: function () {
            return this.context.ACTIVE_ATTRIBUTES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_TEXTURE", {
        get: function () {
            return this.context.ACTIVE_TEXTURE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ACTIVE_UNIFORMS", {
        get: function () {
            return this.context.ACTIVE_UNIFORMS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALIASED_LINE_WIDTH_RANGE", {
        get: function () {
            return this.context.ALIASED_LINE_WIDTH_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALIASED_POINT_SIZE_RANGE", {
        get: function () {
            return this.context.ALIASED_POINT_SIZE_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALPHA", {
        get: function () {
            return this.context.ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALPHA_BITS", {
        get: function () {
            return this.context.ALPHA_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ALWAYS", {
        get: function () {
            return this.context.ALWAYS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ARRAY_BUFFER", {
        get: function () {
            return this.context.ARRAY_BUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ATTACHED_SHADERS", {
        get: function () {
            return this.context.ATTACHED_SHADERS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BACK", {
        get: function () {
            return this.context.BACK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND", {
        get: function () {
            return this.context.BLEND;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_COLOR", {
        get: function () {
            return this.context.BLEND_COLOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_DST_ALPHA", {
        get: function () {
            return this.context.BLEND_DST_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_DST_RGB", {
        get: function () {
            return this.context.BLEND_DST_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION", {
        get: function () {
            return this.context.BLEND_EQUATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION_ALPHA", {
        get: function () {
            return this.context.BLEND_EQUATION_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_EQUATION_RGB", {
        get: function () {
            return this.context.BLEND_EQUATION_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_SRC_ALPHA", {
        get: function () {
            return this.context.BLEND_SRC_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLEND_SRC_RGB", {
        get: function () {
            return this.context.BLEND_SRC_RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BLUE_BITS", {
        get: function () {
            return this.context.BLUE_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL", {
        get: function () {
            return this.context.BOOL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC2", {
        get: function () {
            return this.context.BOOL_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC3", {
        get: function () {
            return this.context.BOOL_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "BOOL_VEC4", {
        get: function () {
            return this.context.BOOL_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CCW", {
        get: function () {
            return this.context.CCW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CLAMP_TO_EDGE", {
        get: function () {
            return this.context.CLAMP_TO_EDGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT0", {
        get: function () {
            return this.context.COLOR_ATTACHMENT0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT0_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT0_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT10_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT10_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT11_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT11_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT12_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT12_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT13_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT13_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT14_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT14_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT15_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT15_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT1_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT1_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT2_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT2_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT3_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT3_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT4_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT4_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT5_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT5_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT6_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT6_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT7_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT7_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT8_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT8_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_ATTACHMENT9_WEBGL", {
        get: function () {
            return this.context.COLOR_ATTACHMENT9_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_BUFFER_BIT", {
        get: function () {
            return this.context.COLOR_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_CLEAR_VALUE", {
        get: function () {
            return this.context.COLOR_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COLOR_WRITEMASK", {
        get: function () {
            return this.context.COLOR_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPILE_STATUS", {
        get: function () {
            return this.context.COMPILE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_R11_EAC", {
        get: function () {
            return this.context.COMPRESSED_R11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RED_GREEN_RGTC2_EXT", {
        get: function () {
            return this.context.COMPRESSED_RED_GREEN_RGTC2_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RED_RGTC1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RED_RGTC1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RG11_EAC", {
        get: function () {
            return this.context.COMPRESSED_RG11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB8_ETC2", {
        get: function () {
            return this.context.COMPRESSED_RGB8_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2", {
        get: function () {
            return this.context.COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA8_ETC2_EAC", {
        get: function () {
            return this.context.COMPRESSED_RGBA8_ETC2_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_10x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_10x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_12x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_12x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_12x12_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_12x12_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_4x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_4x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_5x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_5x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_5x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_5x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_6x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_6x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_6x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_6x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ASTC_8x8_KHR", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ASTC_8x8_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ATC_EXPLICIT_ALPHA_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ATC_EXPLICIT_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_ATC_INTERPOLATED_ALPHA_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGBA_ATC_INTERPOLATED_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_BPTC_UNORM_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_BPTC_UNORM_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_PVRTC_2BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGBA_PVRTC_2BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_PVRTC_4BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGBA_PVRTC_4BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT3_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT3_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGBA_S3TC_DXT5_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGBA_S3TC_DXT5_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_ATC_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGB_ATC_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_BPTC_SIGNED_FLOAT_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_BPTC_UNSIGNED_FLOAT_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_ETC1_WEBGL", {
        get: function () {
            return this.context.COMPRESSED_RGB_ETC1_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_PVRTC_2BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGB_PVRTC_2BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_PVRTC_4BPPV1_IMG", {
        get: function () {
            return this.context.COMPRESSED_RGB_PVRTC_4BPPV1_IMG;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_RGB_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_RGB_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_R11_EAC", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_R11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RED_GREEN_RGTC2_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RED_RGTC1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RED_RGTC1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SIGNED_RG11_EAC", {
        get: function () {
            return this.context.COMPRESSED_SIGNED_RG11_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_10x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_12x10_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_12x12_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_4x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_5x4_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_5x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_6x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_6x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x5_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x6_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ASTC_8x8_KHR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ALPHA8_ETC2_EAC", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ALPHA8_ETC2_EAC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_ETC2", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2", {
        get: function () {
            return this.context.COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_BPTC_UNORM_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_SRGB_S3TC_DXT1_EXT", {
        get: function () {
            return this.context.COMPRESSED_SRGB_S3TC_DXT1_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "COMPRESSED_TEXTURE_FORMATS", {
        get: function () {
            return this.context.COMPRESSED_TEXTURE_FORMATS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CONTEXT_LOST_WEBGL", {
        get: function () {
            return this.context.CONTEXT_LOST_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CULL_FACE", {
        get: function () {
            return this.context.CULL_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CULL_FACE_MODE", {
        get: function () {
            return this.context.CULL_FACE_MODE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CURRENT_PROGRAM", {
        get: function () {
            return this.context.CURRENT_PROGRAM;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CURRENT_VERTEX_ATTRIB", {
        get: function () {
            return this.context.CURRENT_VERTEX_ATTRIB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "CW", {
        get: function () {
            return this.context.CW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DECR", {
        get: function () {
            return this.context.DECR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DECR_WRAP", {
        get: function () {
            return this.context.DECR_WRAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DELETE_STATUS", {
        get: function () {
            return this.context.DELETE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_ATTACHMENT", {
        get: function () {
            return this.context.DEPTH_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_BITS", {
        get: function () {
            return this.context.DEPTH_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_BUFFER_BIT", {
        get: function () {
            return this.context.DEPTH_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_CLEAR_VALUE", {
        get: function () {
            return this.context.DEPTH_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_COMPONENT16", {
        get: function () {
            return this.context.DEPTH_COMPONENT16;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_FUNC", {
        get: function () {
            return this.context.DEPTH_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_RANGE", {
        get: function () {
            return this.context.DEPTH_RANGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_STENCIL", {
        get: function () {
            return this.context.DEPTH_STENCIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_STENCIL_ATTACHMENT", {
        get: function () {
            return this.context.DEPTH_STENCIL_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_TEST", {
        get: function () {
            return this.context.DEPTH_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DEPTH_WRITEMASK", {
        get: function () {
            return this.context.DEPTH_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DITHER", {
        get: function () {
            return this.context.DITHER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DONT_CARE", {
        get: function () {
            return this.context.DONT_CARE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "DYNAMIC_DRAW", {
        get: function () {
            return this.context.DYNAMIC_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ELEMENT_ARRAY_BUFFER", {
        get: function () {
            return this.context.ELEMENT_ARRAY_BUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ELEMENT_ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.ELEMENT_ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "EQUAL", {
        get: function () {
            return this.context.EQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FASTEST", {
        get: function () {
            return this.context.FASTEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT", {
        get: function () {
            return this.context.FLOAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT2", {
        get: function () {
            return this.context.FLOAT_MAT2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT3", {
        get: function () {
            return this.context.FLOAT_MAT3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_MAT4", {
        get: function () {
            return this.context.FLOAT_MAT4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC2", {
        get: function () {
            return this.context.FLOAT_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC3", {
        get: function () {
            return this.context.FLOAT_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FLOAT_VEC4", {
        get: function () {
            return this.context.FLOAT_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAGMENT_SHADER", {
        get: function () {
            return this.context.FRAGMENT_SHADER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAGMENT_SHADER_DERIVATIVE_HINT_OES", {
        get: function () {
            return this.context.FRAGMENT_SHADER_DERIVATIVE_HINT_OES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER", {
        get: function () {
            return this.context.FRAMEBUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_NAME", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_OBJECT_NAME;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL", {
        get: function () {
            return this.context.FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_BINDING", {
        get: function () {
            return this.context.FRAMEBUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_COMPLETE", {
        get: function () {
            return this.context.FRAMEBUFFER_COMPLETE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_ATTACHMENT", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_DIMENSIONS", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_DIMENSIONS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT", {
        get: function () {
            return this.context.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRAMEBUFFER_UNSUPPORTED", {
        get: function () {
            return this.context.FRAMEBUFFER_UNSUPPORTED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT", {
        get: function () {
            return this.context.FRONT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT_AND_BACK", {
        get: function () {
            return this.context.FRONT_AND_BACK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FRONT_FACE", {
        get: function () {
            return this.context.FRONT_FACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_ADD", {
        get: function () {
            return this.context.FUNC_ADD;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_REVERSE_SUBTRACT", {
        get: function () {
            return this.context.FUNC_REVERSE_SUBTRACT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "FUNC_SUBTRACT", {
        get: function () {
            return this.context.FUNC_SUBTRACT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GENERATE_MIPMAP_HINT", {
        get: function () {
            return this.context.GENERATE_MIPMAP_HINT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GEQUAL", {
        get: function () {
            return this.context.GEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GREATER", {
        get: function () {
            return this.context.GREATER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "GREEN_BITS", {
        get: function () {
            return this.context.GREEN_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "IMPLEMENTATION_COLOR_READ_FORMAT", {
        get: function () {
            return this.context.IMPLEMENTATION_COLOR_READ_FORMAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "IMPLEMENTATION_COLOR_READ_TYPE", {
        get: function () {
            return this.context.IMPLEMENTATION_COLOR_READ_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INCR", {
        get: function () {
            return this.context.INCR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INCR_WRAP", {
        get: function () {
            return this.context.INCR_WRAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT", {
        get: function () {
            return this.context.INT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC2", {
        get: function () {
            return this.context.INT_VEC2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC3", {
        get: function () {
            return this.context.INT_VEC3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INT_VEC4", {
        get: function () {
            return this.context.INT_VEC4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_ENUM", {
        get: function () {
            return this.context.INVALID_ENUM;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_FRAMEBUFFER_OPERATION", {
        get: function () {
            return this.context.INVALID_FRAMEBUFFER_OPERATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_OPERATION", {
        get: function () {
            return this.context.INVALID_OPERATION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVALID_VALUE", {
        get: function () {
            return this.context.INVALID_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "INVERT", {
        get: function () {
            return this.context.INVERT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "KEEP", {
        get: function () {
            return this.context.KEEP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LEQUAL", {
        get: function () {
            return this.context.LEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LESS", {
        get: function () {
            return this.context.LESS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR", {
        get: function () {
            return this.context.LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR_MIPMAP_LINEAR", {
        get: function () {
            return this.context.LINEAR_MIPMAP_LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINEAR_MIPMAP_NEAREST", {
        get: function () {
            return this.context.LINEAR_MIPMAP_NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINES", {
        get: function () {
            return this.context.LINES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_LOOP", {
        get: function () {
            return this.context.LINE_LOOP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_STRIP", {
        get: function () {
            return this.context.LINE_STRIP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINE_WIDTH", {
        get: function () {
            return this.context.LINE_WIDTH;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LINK_STATUS", {
        get: function () {
            return this.context.LINK_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LUMINANCE", {
        get: function () {
            return this.context.LUMINANCE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "LUMINANCE_ALPHA", {
        get: function () {
            return this.context.LUMINANCE_ALPHA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_COMBINED_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_COMBINED_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_CUBE_MAP_TEXTURE_SIZE", {
        get: function () {
            return this.context.MAX_CUBE_MAP_TEXTURE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_FRAGMENT_UNIFORM_VECTORS", {
        get: function () {
            return this.context.MAX_FRAGMENT_UNIFORM_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_RENDERBUFFER_SIZE", {
        get: function () {
            return this.context.MAX_RENDERBUFFER_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_TEXTURE_SIZE", {
        get: function () {
            return this.context.MAX_TEXTURE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VARYING_VECTORS", {
        get: function () {
            return this.context.MAX_VARYING_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_ATTRIBS", {
        get: function () {
            return this.context.MAX_VERTEX_ATTRIBS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_TEXTURE_IMAGE_UNITS", {
        get: function () {
            return this.context.MAX_VERTEX_TEXTURE_IMAGE_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VERTEX_UNIFORM_VECTORS", {
        get: function () {
            return this.context.MAX_VERTEX_UNIFORM_VECTORS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MAX_VIEWPORT_DIMS", {
        get: function () {
            return this.context.MAX_VIEWPORT_DIMS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "MIRRORED_REPEAT", {
        get: function () {
            return this.context.MIRRORED_REPEAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST", {
        get: function () {
            return this.context.NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST_MIPMAP_LINEAR", {
        get: function () {
            return this.context.NEAREST_MIPMAP_LINEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEAREST_MIPMAP_NEAREST", {
        get: function () {
            return this.context.NEAREST_MIPMAP_NEAREST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NEVER", {
        get: function () {
            return this.context.NEVER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NICEST", {
        get: function () {
            return this.context.NICEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NOTEQUAL", {
        get: function () {
            return this.context.NOTEQUAL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "NO_ERROR", {
        get: function () {
            return this.context.NO_ERROR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ONE", {
        get: function () {
            return this.context.ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "OUT_OF_MEMORY", {
        get: function () {
            return this.context.OUT_OF_MEMORY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "PACK_ALIGNMENT", {
        get: function () {
            return this.context.PACK_ALIGNMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POINTS", {
        get: function () {
            return this.context.POINTS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_FACTOR", {
        get: function () {
            return this.context.POLYGON_OFFSET_FACTOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_FILL", {
        get: function () {
            return this.context.POLYGON_OFFSET_FILL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "POLYGON_OFFSET_UNITS", {
        get: function () {
            return this.context.POLYGON_OFFSET_UNITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RED_BITS", {
        get: function () {
            return this.context.RED_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER", {
        get: function () {
            return this.context.RENDERBUFFER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_ALPHA_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_ALPHA_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_BINDING", {
        get: function () {
            return this.context.RENDERBUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_BLUE_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_BLUE_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_DEPTH_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_DEPTH_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_GREEN_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_GREEN_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_HEIGHT", {
        get: function () {
            return this.context.RENDERBUFFER_HEIGHT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_INTERNAL_FORMAT", {
        get: function () {
            return this.context.RENDERBUFFER_INTERNAL_FORMAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_RED_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_RED_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_STENCIL_SIZE", {
        get: function () {
            return this.context.RENDERBUFFER_STENCIL_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERBUFFER_WIDTH", {
        get: function () {
            return this.context.RENDERBUFFER_WIDTH;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RENDERER", {
        get: function () {
            return this.context.RENDERER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "REPEAT", {
        get: function () {
            return this.context.REPEAT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "REPLACE", {
        get: function () {
            return this.context.REPLACE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB", {
        get: function () {
            return this.context.RGB;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB32F_EXT", {
        get: function () {
            return this.context.RGB32F_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB565", {
        get: function () {
            return this.context.RGB565;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGB5_A1", {
        get: function () {
            return this.context.RGB5_A1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA", {
        get: function () {
            return this.context.RGBA;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA32F_EXT", {
        get: function () {
            return this.context.RGBA32F_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "RGBA4", {
        get: function () {
            return this.context.RGBA4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLER_2D", {
        get: function () {
            return this.context.SAMPLER_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLER_CUBE", {
        get: function () {
            return this.context.SAMPLER_CUBE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLES", {
        get: function () {
            return this.context.SAMPLES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_ALPHA_TO_COVERAGE", {
        get: function () {
            return this.context.SAMPLE_ALPHA_TO_COVERAGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_BUFFERS", {
        get: function () {
            return this.context.SAMPLE_BUFFERS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE", {
        get: function () {
            return this.context.SAMPLE_COVERAGE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE_INVERT", {
        get: function () {
            return this.context.SAMPLE_COVERAGE_INVERT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SAMPLE_COVERAGE_VALUE", {
        get: function () {
            return this.context.SAMPLE_COVERAGE_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SCISSOR_BOX", {
        get: function () {
            return this.context.SCISSOR_BOX;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SCISSOR_TEST", {
        get: function () {
            return this.context.SCISSOR_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SHADER_TYPE", {
        get: function () {
            return this.context.SHADER_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SHADING_LANGUAGE_VERSION", {
        get: function () {
            return this.context.SHADING_LANGUAGE_VERSION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SRGB8_ALPHA8_EXT", {
        get: function () {
            return this.context.SRGB8_ALPHA8_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STATIC_DRAW", {
        get: function () {
            return this.context.STATIC_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_ATTACHMENT", {
        get: function () {
            return this.context.STENCIL_ATTACHMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_FAIL", {
        get: function () {
            return this.context.STENCIL_BACK_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_FUNC", {
        get: function () {
            return this.context.STENCIL_BACK_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_PASS_DEPTH_FAIL", {
        get: function () {
            return this.context.STENCIL_BACK_PASS_DEPTH_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_PASS_DEPTH_PASS", {
        get: function () {
            return this.context.STENCIL_BACK_PASS_DEPTH_PASS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_REF", {
        get: function () {
            return this.context.STENCIL_BACK_REF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_VALUE_MASK", {
        get: function () {
            return this.context.STENCIL_BACK_VALUE_MASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BACK_WRITEMASK", {
        get: function () {
            return this.context.STENCIL_BACK_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BITS", {
        get: function () {
            return this.context.STENCIL_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_BUFFER_BIT", {
        get: function () {
            return this.context.STENCIL_BUFFER_BIT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_CLEAR_VALUE", {
        get: function () {
            return this.context.STENCIL_CLEAR_VALUE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_FAIL", {
        get: function () {
            return this.context.STENCIL_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_FUNC", {
        get: function () {
            return this.context.STENCIL_FUNC;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_INDEX8", {
        get: function () {
            return this.context.STENCIL_INDEX8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_PASS_DEPTH_FAIL", {
        get: function () {
            return this.context.STENCIL_PASS_DEPTH_FAIL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_PASS_DEPTH_PASS", {
        get: function () {
            return this.context.STENCIL_PASS_DEPTH_PASS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_REF", {
        get: function () {
            return this.context.STENCIL_REF;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_TEST", {
        get: function () {
            return this.context.STENCIL_TEST;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_VALUE_MASK", {
        get: function () {
            return this.context.STENCIL_VALUE_MASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STENCIL_WRITEMASK", {
        get: function () {
            return this.context.STENCIL_WRITEMASK;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "STREAM_DRAW", {
        get: function () {
            return this.context.STREAM_DRAW;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "SUBPIXEL_BITS", {
        get: function () {
            return this.context.SUBPIXEL_BITS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE0", {
        get: function () {
            return this.context.TEXTURE0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE1", {
        get: function () {
            return this.context.TEXTURE1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE10", {
        get: function () {
            return this.context.TEXTURE10;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE11", {
        get: function () {
            return this.context.TEXTURE11;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE12", {
        get: function () {
            return this.context.TEXTURE12;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE13", {
        get: function () {
            return this.context.TEXTURE13;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE14", {
        get: function () {
            return this.context.TEXTURE14;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE15", {
        get: function () {
            return this.context.TEXTURE15;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE16", {
        get: function () {
            return this.context.TEXTURE16;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE17", {
        get: function () {
            return this.context.TEXTURE17;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE18", {
        get: function () {
            return this.context.TEXTURE18;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE19", {
        get: function () {
            return this.context.TEXTURE19;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE2", {
        get: function () {
            return this.context.TEXTURE2;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE20", {
        get: function () {
            return this.context.TEXTURE20;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE21", {
        get: function () {
            return this.context.TEXTURE21;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE22", {
        get: function () {
            return this.context.TEXTURE22;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE23", {
        get: function () {
            return this.context.TEXTURE23;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE24", {
        get: function () {
            return this.context.TEXTURE24;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE25", {
        get: function () {
            return this.context.TEXTURE25;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE26", {
        get: function () {
            return this.context.TEXTURE26;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE27", {
        get: function () {
            return this.context.TEXTURE27;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE28", {
        get: function () {
            return this.context.TEXTURE28;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE29", {
        get: function () {
            return this.context.TEXTURE29;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE3", {
        get: function () {
            return this.context.TEXTURE3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE30", {
        get: function () {
            return this.context.TEXTURE30;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE31", {
        get: function () {
            return this.context.TEXTURE31;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE4", {
        get: function () {
            return this.context.TEXTURE4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE5", {
        get: function () {
            return this.context.TEXTURE5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE6", {
        get: function () {
            return this.context.TEXTURE6;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE7", {
        get: function () {
            return this.context.TEXTURE7;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE8", {
        get: function () {
            return this.context.TEXTURE8;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE9", {
        get: function () {
            return this.context.TEXTURE9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_2D", {
        get: function () {
            return this.context.TEXTURE_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_BINDING_2D", {
        get: function () {
            return this.context.TEXTURE_BINDING_2D;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_BINDING_CUBE_MAP", {
        get: function () {
            return this.context.TEXTURE_BINDING_CUBE_MAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_X", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_X;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Y", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_Y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_NEGATIVE_Z", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_NEGATIVE_Z;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_X", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_X;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Y", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_Y;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_CUBE_MAP_POSITIVE_Z", {
        get: function () {
            return this.context.TEXTURE_CUBE_MAP_POSITIVE_Z;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MAG_FILTER", {
        get: function () {
            return this.context.TEXTURE_MAG_FILTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MAX_ANISOTROPY_EXT", {
        get: function () {
            return this.context.TEXTURE_MAX_ANISOTROPY_EXT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_MIN_FILTER", {
        get: function () {
            return this.context.TEXTURE_MIN_FILTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_WRAP_S", {
        get: function () {
            return this.context.TEXTURE_WRAP_S;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TEXTURE_WRAP_T", {
        get: function () {
            return this.context.TEXTURE_WRAP_T;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLES", {
        get: function () {
            return this.context.TRIANGLES;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLE_FAN", {
        get: function () {
            return this.context.TRIANGLE_FAN;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "TRIANGLE_STRIP", {
        get: function () {
            return this.context.TRIANGLE_STRIP;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_ALIGNMENT", {
        get: function () {
            return this.context.UNPACK_ALIGNMENT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_COLORSPACE_CONVERSION_WEBGL", {
        get: function () {
            return this.context.UNPACK_COLORSPACE_CONVERSION_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_FLIP_Y_WEBGL", {
        get: function () {
            return this.context.UNPACK_FLIP_Y_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNPACK_PREMULTIPLY_ALPHA_WEBGL", {
        get: function () {
            return this.context.UNPACK_PREMULTIPLY_ALPHA_WEBGL;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_BYTE", {
        get: function () {
            return this.context.UNSIGNED_BYTE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_INT", {
        get: function () {
            return this.context.UNSIGNED_INT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT", {
        get: function () {
            return this.context.UNSIGNED_SHORT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_4_4_4_4", {
        get: function () {
            return this.context.UNSIGNED_SHORT_4_4_4_4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_5_5_5_1", {
        get: function () {
            return this.context.UNSIGNED_SHORT_5_5_5_1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "UNSIGNED_SHORT_5_6_5", {
        get: function () {
            return this.context.UNSIGNED_SHORT_5_6_5;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VALIDATE_STATUS", {
        get: function () {
            return this.context.VALIDATE_STATUS;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VENDOR", {
        get: function () {
            return this.context.VENDOR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERSION", {
        get: function () {
            return this.context.VERSION;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_BUFFER_BINDING", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_BUFFER_BINDING;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_ENABLED", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_ENABLED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_NORMALIZED", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_NORMALIZED;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_POINTER", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_POINTER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_SIZE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_SIZE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_STRIDE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_STRIDE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_TYPE", {
        get: function () {
            return this.context.VERTEX_ATTRIB_ARRAY_TYPE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VERTEX_SHADER", {
        get: function () {
            return this.context.VERTEX_SHADER;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "VIEWPORT", {
        get: function () {
            return this.context.VIEWPORT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGLRenderingContext.prototype, "ZERO", {
        get: function () {
            return this.context.ZERO;
        },
        enumerable: true,
        configurable: true
    });
    TNSWebGLRenderingContext.isDebug = false;
    TNSWebGLRenderingContext.filter = 'both';
    return TNSWebGLRenderingContext;
}(canvas_plugin_common_1.TNSWebGLRenderingContextBase));
exports.TNSWebGLRenderingContext = TNSWebGLRenderingContext;
//# sourceMappingURL=TNSWebGLRenderingContext.ios.js.map